@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -221,7 +221,7 @@ DIST_FILES = [
              includefiles=['.*\.py$'],
              ) + \
     listTree('pyformex/icons',
-             includefiles=['README','.*\.xpm$','.*\.png$']
+             includefiles=['README','.*\.xpm$','.*\.png$','.*\.gif$']
              ) + \
     listTree('pyformex/lib',
              includefiles=['.*\.c$','.*\.py$']
