@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -37,10 +37,10 @@ import logging
 import logging.config
 
 __prog__ = "pyformex"
-__version__ = "2.1"
+__version__ = "2.2"
 __revision__ = __version__
 __branch__ = "master"
-Copyright = 'Copyright (C) 2004-2020 Benedict Verhegghe'
+Copyright = 'Copyright (C) 2004-2021 Benedict Verhegghe'
 Url = 'http://pyformex.org'
 Description = ("pyFormex is a tool for generating, manipulating and "
                "transforming large geometrical models of 3D structures "
@@ -403,6 +403,11 @@ def debugt(s, level):
     debug(f"{time.time()}: {s}")
 
 
+def verbosity(verbose):
+    """Check that verbosity is equal or higher than given value"""
+    return options.verbose >= verbose
+
+
 def verbose(verbose, *args, **kargs):
     """Print a message if the verbosity is high enough"""
     if options.verbose >= verbose:
