@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -187,6 +187,8 @@ class Config(Dict):
     Dict({'aa': 'aa', 'rng': [0, 1, 2]})
     >>> C['cc/aa']
     'aa'
+    >>> C.keys()
+    ['aa', 'bb', 'cc', 'cc/aa', 'cc/rng']
 
     Create a new Config with default lookup in C
 
@@ -201,6 +203,8 @@ class Config(Dict):
     'aa'
     >>> D.get('cc/aa','zorro')      # but get method does not cascade!
     'zorro'
+    >>> D.keys()
+    []
 
     Setting values in D will store them in D while C remains unchanged.
 
@@ -303,7 +307,7 @@ class Config(Dict):
         Returns
         -------
         Config
-            Returns the Config self, update with the settings read from
+            Returns the Config self, updated with the settings read from
             the specified file.
         """
         Config._filename = Path(filename)
@@ -492,7 +496,13 @@ class Config(Dict):
     def keys(self, descend=True):
         """Return the keys in the config.
 
-        By default this descends one level of Dicts.
+        Parameters
+        ----------
+        descend: bool, optional
+            If True (default) also reports the keys in Dict objects with
+            the combined section/item keys. This is the proper use for a
+            Config with optional sections.
+            If False, no keys in sections are reported, only the section names.
         """
         keys = list(Dict.keys(self))
         if descend:
