@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -24,8 +24,6 @@
 """Barrel Vault Shell
 
 """
-
-
 _status = 'checked'
 _level = 'beginner'
 _topics = ['frame']
@@ -38,13 +36,15 @@ def run():
     smoothwire()
 
     res = askItems([
-        dict(name='m', value=12, text='number of modules in axial direction'),
-        dict(name='n', value=8, text='number of modules in tangential direction'),
-        dict(name='r', value=10., text='barrel radius'),
-        dict(name='a', value=180., text='barrel opening angle'),
-        dict(name='l', value=30., text='barrel length'),
-        dict(name='eltype', value='quad8', text='element type', itemtype='radio', choices=['tri3', 'quad4', 'quad8', 'quad9']),
+        _I('m', 12, min=1, text='number of modules in axial direction'),
+        _I('n', 8, min=1, text='number of modules in tangential direction'),
+        _I('r', 10., text='barrel radius'),
+        _I('a', 180., text='barrel opening angle'),
+        _I('l', 30., text='barrel length'),
+        _I('eltype', 'quad8', text='element type', itemtype='radio',
+           choices=['tri3', 'quad4', 'quad8', 'quad9']),
         ])
+    print(res)
     if not res:
         return
 
