@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -34,6 +34,7 @@ _topics = ['mesh', 'illustration', 'surface']
 _techniques = ['color', 'random', 'image', 'movie', 'extrude']
 
 from pyformex.gui.draw import *
+from pyformex.gui import image
 from pyformex.plugins import surface_menu
 from pyformex.elements import *
 
@@ -112,6 +113,7 @@ def run():
         canvasSize(nx*200, ny*200)
         #canvasSize(720,576)
         print("running interactively")
+        print(Path.cwd())
         res = askItems([
             _I('n', 1, text='Number of carpets'),
             _I('save', False, text='Save images'),
@@ -122,8 +124,9 @@ def run():
         n = res['n']
         save = res['save']
         if save:
-            from pyformex.gui import image
-            image.save(filename='Carpetry-000.jpg', window=False, multi=True, hotkey=False, autosave=False, border=False, format=None, quality=95, verbose=False)
+            image.saveImage(filename='Carpetry-000.jpg', multi=True,
+                            hotkey=False, autosave=False, quality=95,
+                            verbose=False)
 
         A = None
         for i in range(n):
@@ -137,9 +140,9 @@ def run():
                 image.saveNext()
 
         if save:
-            files = utils.globFiles(image.multisave[0].glob())
-            image.createMovie(files, encoder='convert', delay=1, colors=256)
-            image.save()   # reset the multisave mode, disabling further saves
+            image.saveImage()  # turn off multisave mode
+            # files = utils.globFiles(image.multisave['filename'].glob())
+            # image.createMovie(files, encoder='convert', delay=1, colors=256)
 
     else:
         import sys
@@ -147,10 +150,10 @@ def run():
         print(argv)
         canvasSize(nx*200, ny*200)
         print("just saving image")
-        from pyformex.gui import image, guimain
+        from pyformex.gui import guimain
         with busyCursor():
             carpet(M)
-        image.save('testje2.png')
+        image.saveImage('testje2.png')
         #return(all=True)
         guimain.quitGUI()
 
