@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -79,9 +79,9 @@ def run():
     # And now something more fancy: connect 1 out of 15 points of the circles
 
     res = askItems([
-        ('Connect circles', True),
-        ('Create Triangles', True),
-        ('Fly Through', True),
+        _I('Connect circles', True),
+        _I('Create Triangles', True),
+        _I('Fly Through', True),
         ])
 
     if res:
