@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -61,12 +61,12 @@ def run():
         if key in result:
             draw(result[key])
 
-    dia = Dialog(caption="ClippingBox", items=[
+    dialog = Dialog(caption="ClippingBox", items=[
         _I('info', "Which surface to display?", itemtype='label', text=''),
         _I('key', choices=list(result.keys()), itemtype='hpush', func=show,
            text=''),
     ], actions=[('Cancel',)])
-    dia.show()
+    dialog.show()
 
 
 if __name__ == '__draw__':
