@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -24,7 +24,7 @@
 """ColorImage
 
 This example illustrates how to display and transform 2D images.
-First, a 2D image is read from a file. You can select a file by clicking ont
+First, a 2D image is read from a file. You can select a file by clicking on
 the filename button.
 Then a grid type geometry is constructed. The size of the grid can be set,
 and the image will be rescaled to that size.
@@ -67,9 +67,9 @@ def loadImage(fn):
     w, h = image.width(), image.height()
     print("size = %sx%s" % (w, h))
 
-    diag = currentDialog()
-    if diag:
-        diag.updateData({'nx': w, 'ny': h})
+    dialog = currentDialog()
+    if dialog:
+        dialog.updateData({'nx': w, 'ny': h})
 
     maxsiz = 40000.
     if w*h > maxsiz:
@@ -97,17 +97,20 @@ def run():
 
     transforms = OrderedDict([
         ('flat', lambda F: F),
-        ('cylindrical', lambda F: F.cylindrical([2, 0, 1], [2., 90./float(nx), 1.]).rollAxes(-1)),
-        ('spherical', lambda F: F.spherical(scale=[1., 90./float(nx), 2.]).rollAxes(-1)),
+        ('cylindrical', lambda F: F.cylindrical(
+            [2, 0, 1], [2., 90./float(nx), 1.]).rollAxes(-1)),
+        ('spherical', lambda F: F.spherical(
+            scale=[1., 90./float(nx), 2.]).rollAxes(-1)),
         ('projected_on_cylinder', lambda F: F.projectOnCylinder(2*R, 1)),
         ])
 
     res = askItems([
-        _I('filename', filename, text='Image file', itemtype='button', func=selectImage),
+        _I('filename', filename, text='Image file', itemtype='push',
+           func=selectImage),
         viewer,   # image previewing widget
         _I('nx', w, text='width'),
         _I('ny', h, text='height'),
-        _I('transform', itemtype='vradio', choices=tuple(transforms.keys())),
+        _I('transform', itemtype='hradio', choices=list(transforms.keys())),
         ])
 
 
