@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -60,14 +60,16 @@ def run():
     fonts = utils.listMonoFonts()
 
     ftmin, ftmax = 12, 48
+    rotmin, rotmax = -90., +90.
 
-    r = random.random((n, 8))
+    R = random.random((n, 9))
     w, h = pf.canvas.width(), pf.canvas.height()
-    a = r[:, :2] * array([w, h]).astype(int)
-    size = (ftmin + r[:, 2] * (ftmax-ftmin)).astype(int)
-    colors = r[:, 3:6]
-    t = (r[:, 6] * len(T)).astype(int)
-    f = (r[:, 7] * len(fonts) - 0.5).astype(int).clip(0, len(fonts)-1)
+    a = R[:, :2] * array([w, h]).astype(int)
+    size = (ftmin + R[:, 2] * (ftmax-ftmin)).astype(int)
+    colors = R[:, 3:6]
+    t = (R[:, 6] * len(T)).astype(int)
+    f = (R[:, 7] * len(fonts) - 0.5).astype(int).clip(0, len(fonts)-1)
+    rot = rotmin + R[:, 8] * (rotmax-rotmin)
     clear()
 
     bgcolor(white)
@@ -75,9 +77,10 @@ def run():
     TA = None
 
 
-    for i, s in enumerate(size):
-        TB = drawText(T[t[i]], a[i], font=fonts[f[i]], size=s, color=list(colors[i]))
-        sleep(0.5)
+    for i in arange(n):
+        TB = drawText(T[t[i]], a[i], font=fonts[f[i]], size=size[i],
+                      color=list(colors[i]), rotate=rot[i])
+        sleep(0.4)
         breakpt()
         if i < n//2:
             undecorate(TA)
