@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -121,13 +121,11 @@ diag=''
 
 def run():
     items = [
-        widgets.simpleInputItem(n, globals()[n])
-        for n in ['r0', 'r1', 'h', 't', 'nr', 'nt']
+        _I(n, globals()[n]) for n in ['r0', 'r1', 'h', 't', 'nr', 'nt']
         ] + [
-        widgets.simpleInputItem('diag', diag, itemtype='radio', choices=['', 'u', 'd'])
+        _I('diag', diag, itemtype='radio', choices=['', 'u', 'd'])
         ]
-    dialog = widgets.InputDialog(items)
-
+    dialog = Dialog(items)
 
     while not dialog.result() == widgets.TIMEOUT:
         res = dialog.getResults()
@@ -144,7 +142,6 @@ def run():
         draw(H)
         return
 
-#return
 
 if __name__ == '__draw__':
     run()
