@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -216,7 +216,8 @@ def close():
 
 
 def show(all=False):
-    dialog.acceptData()
+    if not dialog.validate():
+        return
     res = dialog.results
     if res['AutoUpVector']:
         res['UpVector'] = None
@@ -255,8 +256,7 @@ def run():
         #print pf.PF['_Curves_data_']
         dialog.updateData(pf.PF['_Curves_data_'])
 
-    dialog.timeout = timeOut
-    dialog.show()
+    dialog.show(timeoutfunc=timeOut)
     # Block other scripts
     scriptLock(__file__)
 
