@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -39,7 +39,11 @@ def run():
 
     m=n=6
     f=0.8
-    res = askItems([('m', m), ('n', n), ('f', f)])
+    res = askItems([
+        _I('m', m),
+        _I('n', n),
+        _I('f', f),
+    ])
     if not res:
         return
 
