@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -51,11 +51,11 @@ def run():
     SA = draw(S)
 
     res = askItems([
-        ('direction', [1., 0., 0.]),
-        ('number of sections', 20),
-        ('color', 'red'),
-        ('ontop', False),
-        ('remove surface', False),
+        _I('direction', [1., 0., 0.]),
+        _I('number of sections', 20),
+        _I('color', 'red'),
+        _I('ontop', False),
+        _I('remove surface', False),
         ])
     if not res:
         return
