@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -22,13 +22,11 @@
 ##  along with this program.  If not, see http://www.gnu.org/licenses/.
 ##
 
-"""InputDialog
-
-Example showing the use of input dialogs.
+"""Dialog
 
+Example demonstrating the components of input dialogs.
 """
 
-
 _status = 'failed'
 _level = 'normal'
 _topics = []
@@ -38,55 +36,63 @@ from pyformex.gui.draw import *
 
 # BV
 # not working correctly:
-# - itemtype = 'label'
-# - bounds on 'float'
-# - fslider has no slider
+# - fslider doesn't work
 # - tooltip on group/tab
-# - push does not work correctly
 
 input_text = [
-    dict(name='label', value=None, text="A constant info field", itemtype='info', tooltip="itemtype='info' with a value=None can be used to show a label only. Note that this does not work with the _I() function."),
+    _I('label', text="Just a label without value", itemtype='label', tooltip="itemtype='label' without value."),
+     _I('labeltxt', text="", itemtype='label', tooltip="itemtype='label' and value in reStructuredText.", value="""..
+
+Header
+------
+A label with a value. In this case some text written in reStructuredText.
+The label text is empty.
+"""),
     _I('info', 'A constant info field', text="itemtype 'info'", itemtype='info', tooltip="This is an informational field that can not be changed"),
     _I('string', 'A string input field', text="itemtype str", itemtype='string', tooltip="This is a single line string input field"),
     _I('text', 'A multiline text input field', text="itemtype 'text'", itemtype='text', tooltip="This is a multiline text input field"),
-    ]
+]
+
+input_select_1 = [
+    _I('bool', False, text="itemtype bool", stretch='ba', tooltip="This is a boolean field that can only get the values True or False, by checking or unchecking the box"),
+    _I('list', ['First', 'Third'], text="itemtype 'list'", itemtype='list', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="This is a an input field allowing you to select one or more of a set of predefined values"),
+    _I('slist', ['First', 'Third'], text="itemtype 'list' (single)", itemtype='list', choices=['First', 'Second', 'Third', 'Fourth'], single=True, tooltip="This is like 'list', but allowing only a single value to be selected"),
+    _I('clist', ['First', 'Third'], text="itemtype 'list' (check)", itemtype='list', choices=['First', 'Second', 'Third', 'Fourth'], check=True, tooltip="This is a an input field allowing you to select one of a set of predefined values"),
+]
+
+input_select_2 = [
+    _I('select', 'Third', text="itemtype 'combo'", itemtype='combo', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="This is a an input field allowing you to select one of a set of predefined values"),
+    _I('radio', 'Third', text="itemtype (h)radio", itemtype='radio', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="Like 'select', this allows selecting one of a set of predefined values"),
+    _I('vradio', 'Third', text="itemtype (v)radio", itemtype='vradio', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="Like 'radio', but items are placed vertically"),
+        _I('push','Third',text="itemtype (h)push",itemtype='push', choices=['First','Second','Third','Fourth'],tooltip="Yet another method to select one of a set of predefined values"),
+        _I('vpush','Third',text="itemtype (v)push",itemtype='vpush', choices=['First','Second','Third','Fourth'],tooltip="Like 'push', but items are placed vertically"),
+]
 
 input_select = [
-    _H('sel', [
-        _I('bool', False, text="itemtype bool", stretch='ba', tooltip="This is a boolean field that can only get the values True or False, by checking or unchecking the box"),
-        _I('list', ['First', 'Third'], text="itemtype 'list'", itemtype='list', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="This is a an input field allowing you to select one or more of a set of predefined values"),
-        _I('slist', ['First', 'Third'], text="itemtype 'list' with single=True", itemtype='list', choices=['First', 'Second', 'Third', 'Fourth'], single=True, tooltip="This is like 'list', bu allowing only a single value to be selected"),
-        _I('clist', ['First', 'Third'], text="itemtype 'list' with check=True", itemtype='list', choices=['First', 'Second', 'Third', 'Fourth'], check=True, tooltip="This is a an input field allowing you to select one of a set of predefined values"),
-    ], maxwidth=500),
-    _H('sel', [
-        _I('select', 'Third', text="itemtype 'select'", choices=['First', 'Second', 'Third', 'Fourth'], tooltip="This is a an input field allowing you to select one of a set of predefined values"),
-        _I('radio', 'Third', text="itemtype (h)radio", itemtype='radio', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="Like 'select', this allows selecting one of a set of predefined values"),
-        _I('vradio', 'Third', text="itemtype vradio", itemtype='vradio', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="Like 'radio', but items are placed vertically"),
-    #    _I('push','Third',text="itemtype (h)push",itemtype='push',choices=['First','Second','Third','Fourth'],tooltip="Yet another method to select one of a set of predefined values"),
-    #    _I('vpush','Third',text="itemtype vpush",itemtype='vpush',choices=['First','Second','Third','Fourth'],tooltip="Like 'push', but items are placed vertically"),
-    ], maxwidth=500),
+    _C('sel', input_select_1, maxwidth=600),
+    _C('sel', input_select_2, maxwidth=600),
     ]
 
 input_numerical = [
     _I('integer', 37, text="any int", tooltip="An integer input field"),
-    _I('bounded', 3, text="a bounded integer (0..10)", min=0, max=10, tooltip="A bounded integer input field. This value is e.g. bounded to the interval [0,10]"),
+    _I('bounded', 50, text="a bounded integer (45..55)", min=45, max=55, tooltip="Accepts an integer in the interval [45,55]"),
     _I('float', 37., text="any float", tooltip="A float input field"),
     _I('boundedf', 23.7, text="a bounded float", min=23.5, max=23.9, tooltip="A bounded float input field. This value is e.g. bounded to the interval [23.5,23.9]"),
     _I('slider', 3, text="a integer slider", min=0, max=10, itemtype='slider', tooltip="An integer input field accompanied by a slider to set the value."),
     _I('fslider', 23.7, text="a float slider", min=23.5, max=23.9, itemtype='fslider', tooltip="A float input field accompanied by a slider to set the value."),
-    _I('ivector', [640, 400], text="an integer vector", tooltip="An integer vector input field"),
+    _I('ivector', [640, 400], itemtype='ivector', text="an integer vector", tooltip="An integer vector input field"),
     ]
 
 input_special = [
     _I('color', colors.pyformex_pink, itemtype='color', text="Color", tooltip="An inputfield allowing to select a color. The current color is pyFormex pink."),
     _I('font', '', itemtype='font'),
     _I('point', [0., 0., 0.], itemtype='point'),
-    _H('column1', [
+    _C('column1', [
         _I('point1', [0., 0., 0.], itemtype='point'),
         _I('point2', [0., 0., 0.], itemtype='point'),
         _I('point3', [0., 0., 0.], itemtype='point'),
        ], maxwidth=500),
-    _H('column2', [
+    _C('column2', [
         _I('point4', [0., 0., 0.], itemtype='point'),
         _I('point5', [0., 0., 0.], itemtype='point'),
        ], maxwidth=500),
@@ -95,46 +101,43 @@ input_special = [
 
 input_tabgroup = [
     _I('enable1', False, text="Enable group 1"),
-    _G('group1', input_text, text="Text input group"),
+    _G('group1', input_text[1:4], text="Text input group"),
     _I('enable2', False, text="Enable group 2"),
-    _G('group2', input_select, text="Select input group"),
-    _G('group3', input_special, text="Special input group", checkable=True, checked=True),
+    _G('group2', input_select_1[:3], text="Select input group"),
+    _G('group3', input_special[:3], text="Special input group", check=True),
     ]
 
 input_data = [
-    _T('Text', input_text, width=600),
+    _T('Text', input_text[:3], width=600),
     _T('Selection', input_select, width=600),
     _T('Numerical', input_numerical, width=600),
     _T('Special', input_special, width=600),
-    _T('tabgroup', input_tabgroup, text="Tabs and Groups", width=600),
+    _T('tabgroup', input_tabgroup, text="Groups", width=600),
     ]
 
 input_enablers = [
-    ('tabgroup/enable1', True, 'tabgroup/group1', 'tabgroup/group2/sel/radio'),
-    ('tabgroup/enable2', True, 'tabgroup/group2', 'tabgroup/group3', 'tabgroup/group1/info'),
+    ('tabgroup/enable1', True, 'tabgroup/group1'), # 'tabgroup/group2/sel/radio'),
+    ('tabgroup/enable2', True, 'tabgroup/group2', 'tabgroup/group3', 'tabgroup/group1/string'),
     ]
 
 
 def show():
     """Accept the data and show the results"""
-    from pyformex.utils import formatDict
-    dialog.acceptData()
-    res = dialog.results
-    print(formatDict(res))
+    if dialog.validate():
+        showText(utils.formatDict(dialog.results))
 
 
 def close():
     global dialog
-    pf.PF['ColorScale_data'] = dialog.results
     if dialog:
         dialog.close()
         dialog = None
-    print("# Release script lock")
+    #print("# Release script lock")
     scriptRelease(__file__)
 
 
 def timeOut():
-    """What to do on a InputDialog timeout event.
+    """What to do on a Dialog timeout event.
 
     As a policy, all pyFormex examples should behave well on a
     dialog timeout.
@@ -146,26 +149,17 @@ def timeOut():
 
 def run():
     global dialog
-    # Update the data items from saved values
-    try:
-        saved_data = named('InputDialog_data')
-        widgets.updateDialogItems(input_data, save_data)
-    except Exception:
-        pass
 
     # Create the modeless dialog widget
     dialog = Dialog(input_data, enablers=input_enablers, autoprefix=True,
-                    caption='InputDialog',
+                    caption='Dialog',
                     actions = [('Close', close), ('Show', show)],
                     default='Show',
                     scroll=True, size=(0.75, 0.85)
     )
 
-    # Examples style requires a timeout action
-    dialog.timeout = timeOut
-
     # Show the dialog and let the user have fun
-    dialog.show()
+    dialog.show(timeoutfunc=timeOut)
 
     # Block other scripts
     scriptLock(__file__)
