@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -109,7 +109,8 @@ def show(i, L, turtle_cmds, clear=True, text=True, color=0, lw=1.):
             TA = TB
 
 
-def grow(rule='', clearing=True, text=True, ngen=-1, colors=True, viewports=False):
+def grow(rule='', clearing=True, text=True, ngen=-1,
+         colors=True, viewports=False):
     """Show subsequent Lima productions."""
     global FA, TA
     FA = None
@@ -143,13 +144,13 @@ def grow(rule='', clearing=True, text=True, ngen=-1, colors=True, viewports=Fals
         show(i+1, L, t, clearing, text, color=i if colors else 0, lw=(g-i)*1.0)
 
 
-def setDefaultGenerations(rule):
-    rule = str(rule)
+def setDefaultGenerations(fld):
+    rule = fld.value()
     if rule in limas:
         ngen = limas[rule][2]
-        d = currentDialog()
-        if d:
-            d.updateData({'ngen': ngen})
+        dialog = fld.dialog()
+        if dialog:
+            dialog.updateData({'ngen': ngen})
 
 
 def run():
@@ -160,7 +161,6 @@ def run():
     wireframe()
     linewidth(2)
     keys = list(limas.keys())
-    #keys.sort()
     choices = ['__all__', '__custom__'] + keys
 
     defaults = {
@@ -174,12 +174,13 @@ def run():
     defaults = pf.PF.get('__Lima__data', defaults)
 
     res = askItems([
-        dict(name='rule', value=defaults['rule'], text='Production rule', choices=choices, onselect=setDefaultGenerations),
-        dict(name='ngen', value=defaults['ngen'], text='Number of generations (-1 = default)'),
-        dict(name='colors', value=defaults['colors'], text='Use different colors per generation'),
-        dict(name='clearing', value=defaults['clearing'], text='Clear screen between generations'),
-        dict(name='viewports', value=defaults['viewports'], text='Use a separate viewport for each generation'),
-        ])
+        _I('rule', text='Production rule',
+           choices=choices, func=setDefaultGenerations),
+        _I('ngen', text='Number of generations (-1 = default)'),
+        _I('colors', text='Use different colors per generation'),
+        _I('clearing', text='Clear screen between generations'),
+        _I('viewports', text='Use a separate viewport for each generation'),
+        ], store=defaults)
 
     if res:
         pf.PF['__Lima__data'] = res.copy()
