@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -26,7 +26,6 @@
 Find the intersection points of polylines
 """
 
-
 _status = 'checked'
 _level = 'normal'
 _topics = ['curve']
@@ -61,6 +60,8 @@ def intersection(F1, F2):
 
     # Compute all intersection points of the lines
     t1, t2 = gt.intersectLineWithLine(q1, m1, q2, m2, mode='all', times=True)
+    t1 = np.nan_to_num(t1)
+    t2 = np.nan_to_num(t2)
     X1 = pointsAtLines(q1[:, newaxis], m1[:, newaxis], t1)
     X2 = pointsAtLines(q2, m2, t2)
 
