@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -36,7 +36,7 @@ from pyformex.opengl.textext import *
 
 def run():
     reset()
-    smoothwire()
+    smooth()
 
     res = askItems([
         _I('w', 3, text='width', tooltip='Number of unit squares along the width'),
