@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -140,19 +140,19 @@ def close():
 
 
 def show():
-    dialog.acceptData()
-    res = dialog.results
-    export({'_Nurbs_data_': res})
-    drawNurbs(**res)
+    if dialog.validate():
+        res = dialog.results
+        export({'_Nurbs_data_': res})
+        drawNurbs(**res)
 
 def showAll():
-    dialog.acceptData()
-    res = dialog.results
-    export({'_Nurbs_data_': res})
-    for points in predefined:
-        print(res)
-        res['points'] = points
-        drawNurbs(**res)
+    if dialog.validate():
+        res = dialog.results
+        export({'_Nurbs_data_': res})
+        for points in predefined:
+            print(res)
+            res['points'] = points
+            drawNurbs(**res)
 
 
 def timeOut():
@@ -184,7 +184,7 @@ predefined = [
 
 data_items = [
     _I('points', text='Point set', choices=predefined),
-    _I('pointtype', text='Point type', itemtype='select', choices=['Control', 'OnCurve']),
+    _I('pointtype', text='Point type', choices=['Control', 'OnCurve']),
     _I('degree', 3),
     _I('strategy', 0.5),
     _I('closed', False),
@@ -227,8 +227,7 @@ def run():
     if '_Nurbs_data_' in pf.PF:
         dialog.updateData(pf.PF['_Nurbs_data_'])
 
-    dialog.timeout = timeOut
-    dialog.show()
+    dialog.show(timeoutfunc=timeOut)
 
     # Block other scripts
     scriptLock(__file__)
