@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -127,20 +127,23 @@ def close():
 
 
 def show():
-    dialog.acceptData()
-    res = dialog.results
-    export({'_Nurbs_data_': res})
-    drawNurbs(**res)
+    if dialog.validate():
+        res = dialog.results
+        export({'_Nurbs_data_': res})
+        drawNurbs(**res)
 
 def showAll():
-    dialog.acceptData()
-    res = dialog.results
-    export({'_Nurbs_data_': res})
-    for points in point_ids:
-        print(res)
-        res['points'] = points
-        drawNurbs(**res)
-        sleep(1)
+    if dialog.validate():
+        res = dialog.results
+        export({'_Nurbs_data_': res})
+        for points in point_ids:
+            if len(points) <= res['degree']:
+                print(f"Skipping point set: {points}: {len(points) + 1}"
+                      f" points required for degree {res['degree']}")
+                continue
+            res['points'] = points
+            drawNurbs(**res)
+            sleep(1)
 
 
 def timeOut():
@@ -177,8 +180,7 @@ def run():
     if '_Nurbs_data_' in pf.PF:
         dialog.updateData(pf.PF['_Nurbs_data_'])
 
-    dialog.timeout = timeOut
-    dialog.show()
+    dialog.show(timeoutfunc=timeOut)
 
     # Block other scripts
     scriptLock(__file__)
