@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -32,7 +32,6 @@ Illustrates some special techniques on Nurbs Curves:
 - degree elevation
 """
 
-
 _status = 'checked'
 _level = 'advanced'
 _topics = ['Geometry', 'Curve']
@@ -50,20 +49,13 @@ from pyformex.lib import nurbs
 def showCurve(reverse=False):
     """Select and show a Nurbs curve."""
     global N, dialog
-
-    if dialog:
-        dialog.acceptData()
-        res = dialog.results
-        curv = res['curv']
-    else:
-        curv = ''
-
-    N = createNurbs(curv)
-    if reverse:
-        N = N.reverse()
-    print(N)
-    drawNurbs(N, color=blue, knotsize=5)
-
+    if dialog.validate():
+        curv = dialog.results['curv']
+        N = createNurbs(curv)
+        if reverse:
+            N = N.reverse()
+        print(N)
+        drawNurbs(N, color=blue, knotsize=5)
 
 
 def showReverse():
@@ -74,59 +66,59 @@ def insertKnot():
     """Insert a knot in the knot vector of Nurbs curve N."""
     global N, dialog
 
-    dialog.acceptData()
-    res = dialog.results
-    u = eval('[%s]' % res['u'])
-    N = N.insertKnots(u)
-    print(N)
-    drawNurbs(N, color=red, knotsize=5)
-    zoomAll()
+    if dialog.validate():
+        res = dialog.results
+        u = eval('[%s]' % res['u'])
+        N = N.insertKnots(u)
+        print(N)
+        drawNurbs(N, color=red, knotsize=5)
+        zoomAll()
 
 
 def removeKnot():
     """Remove a knot from the knot vector of Nurbs curve N."""
     global N, dialog
 
-    dialog.acceptData()
-    res = dialog.results
-    ur = res['ur']
-    m = res['m']
-    tol = res['tol']
-    N = N.removeKnot(ur, m, tol)
-    print(N)
-    drawNurbs(N, color=blue, knotsize=5)
-    zoomAll()
+    if dialog.validate():
+        res = dialog.results
+        ur = res['ur']
+        m = res['m']
+        tol = res['tol']
+        N = N.removeKnot(ur, m, tol)
+        print(N)
+        drawNurbs(N, color=blue, knotsize=5)
+        zoomAll()
 
 
 def removeAllKnots():
     """Remove all removable knots."""
     global N, dialog
 
-    dialog.acceptData()
-    res = dialog.results
-    tol = res['tol']
-    N = N.removeAllKnots(tol=tol)
-    print(N)
-    drawNurbs(N, color=blue)
-    zoomAll()
+    if dialog.validate():
+        res = dialog.results
+        tol = res['tol']
+        N = N.removeAllKnots(tol=tol)
+        print(N)
+        drawNurbs(N, color=blue)
+        zoomAll()
 
 
 def elevateDegree():
     """Elevate the degree of the Nurbs curve N."""
     global N, dialog
 
-    dialog.acceptData()
-    res = dialog.results
-    nd = res['nd']
-    if nd > 0:
-        N = N.elevateDegree(nd)
-    elif nd < 0:
-        N = N.reduceDegree(-nd)
-    else:
-        return
-    print(N)
-    draw(N, color=cyan, linewidth=3)
-    zoomAll()
+    if dialog.validate():
+        res = dialog.results
+        nd = res['nd']
+        if nd > 0:
+            N = N.elevateDegree(nd)
+        elif nd < 0:
+            N = N.reduceDegree(-nd)
+        else:
+            return
+        print(N)
+        draw(N, color=cyan, linewidth=3)
+        zoomAll()
 
 
 def decompose():
@@ -163,20 +155,20 @@ def projectPoints():
     """Project points on the NurbsCurve N"""
     global N, dialog
 
-    dialog.acceptData()
-    res = dialog.results
-    npts = res['npts']
-    show_distance = res['show_distance']
+    if dialog.validate():
+        res = dialog.results
+        npts = res['npts']
+        show_distance = res['show_distance']
 
-    X = simple.randomPoints(npts, N.bbox())
-    draw(X, marksize=5)
+        X = simple.randomPoints(npts, N.bbox())
+        draw(X, marksize=5)
 
-    for Xi in X:
-        u, P = N.projectPoint(Xi)
-        draw(Formex([[P, Xi]]), color=red)
-        if show_distance:
-            d = at.length(P-Xi)
-            drawText("%s" %d, 0.5*(P+Xi))
+        for Xi in X:
+            u, P = N.projectPoint(Xi)
+            draw(Formex([[P, Xi]]), color=red)
+            if show_distance:
+                d = at.length(P-Xi)
+                drawText("%s" %d, 0.5*(P+Xi))
 
 
 def close():
@@ -241,14 +233,12 @@ def run():
             ('(Un)Clamp', unclamp),
             ('Decompose', decompose),
         ])
-    dialog.timeout = timeOut
-    dialog.show()
+    dialog.show(timeoutfunc=timeOut)
 
     # Block other scripts
     scriptLock(__file__)
 
 
-
 if __name__ == '__draw__':
     run()
 
