@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -106,20 +106,20 @@ def run():
 
     # what to draw
     options = askItems(store=globals(), items=[
-        ('draw_points',),
-        ('draw_surf',),
-        ('draw_curves',),
-        ('draw_curvepoints', ),
-        ('draw_isocurves', ),
-        ('draw_tangents', ),
-        ('draw_randompoints', ),
+        _I('draw_points',),
+        _I('draw_surf',),
+        _I('draw_curves',),
+        _I('draw_curvepoints', ),
+        _I('draw_isocurves', ),
+        _I('draw_tangents', ),
+        _I('draw_randompoints', ),
         ])
 
     if not options:
         return
 
     globals().update(options)
-    print(options)
+    print(f"Options: {options}")
 
     ###########################
     ####   CONTROL GRID
