@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -32,7 +32,6 @@ objects. Attributes that can be changed include color, opacity, visibility,
 
 """
 
-
 _status = 'checked'
 _level = 'normal'
 _topics = ['export']
@@ -66,9 +65,9 @@ def run():
     zoomAll()
 
     # create an object dialog
-    dia = objectDialog(drawn_objects)
-    if dia:
-        dia.show()
+    dialog = objectDialog(drawn_objects)
+    if dialog:
+        dialog.show()
 
 
 if __name__ == '__draw__':
