@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -496,7 +496,8 @@ def close():
 def explain():
     """Show the explanation"""
     global explanation
-    dialog.acceptData()
+    if not dialog.validate():
+        return
     globals().update(dialog.results)
     text = method[Illusion].__doc__
     if Explain:
@@ -515,7 +516,8 @@ def explain():
 def show():
     """Show the illusion"""
     if dialog:
-        dialog.acceptData()
+        if not dialog.validate():
+            return
         globals().update(dialog.results)
         if Explain:
             explain()
@@ -526,7 +528,8 @@ def show():
 
 def next():
     """Show the next illusion"""
-    dialog.acceptData()
+    if not dialog.validate():
+        return
     ill = dialog.results['Illusion']
     i = (method._order.index(ill) + 1) % len(method._order)
     dialog.updateData({'Illusion': method._order[i]})
@@ -549,7 +552,7 @@ def openDialog():
         _I('Explain', Explain, text='Show explanation'),
         ]
 
-    dialog = widgets.InputDialog(
+    dialog = widgets.Dialog(
         data_items,
         caption='Optical illusions',
         actions = [('Done', close),
@@ -558,8 +561,7 @@ def openDialog():
                    ('Show', show)],
         default='Show'
         )
-    dialog.timeout = timeOut
-    dialog.show()
+    dialog.show(timeoutfunc=timeOut)
 
 
 def run():
