@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -37,7 +37,7 @@ _techniques = ['rectangular', 'seed', 'layout']
 
 
 from pyformex.gui.draw import *
-from pyformex.plugins.mesh_ext import *
+from pyformex.mesh import rectangle
 from pyformex.gui.menus.Viewport import clearAll
 
 
@@ -49,9 +49,14 @@ def run():
     clearAll()
     smoothwire()
     fgcolor(red)
+    print(pf.canvas.settings)
     layout(6, 3)
 
+    # Viewports are not correctly initialized!
+    # we need to reset canvas settings
     viewport(0)
+    smoothwire()
+    fgcolor(red)
     M = rectangle(1., 1., 6, 3)
     draw(M)
 
@@ -60,18 +65,26 @@ def run():
     draw(M)
 
     viewport(2)
+    smoothwire()
+    fgcolor(red)
     M = rectangle(1., 1., (6, 0.3), (6, -0.5))
     draw(M)
 
     viewport(3)
+    smoothwire()
+    fgcolor(red)
     M = rectangle(1., 1., (6, 0.5, 0.5), (6, 1, 1))
     draw(M)
 
     viewport(4)
+    smoothwire()
+    fgcolor(red)
     M = rectangle(1., 1., (6, -1, -1), (6, -1, -1))
     draw(M)
 
     viewport(5)
+    smoothwire()
+    fgcolor(red)
     M = rectangle(2., 1., (6, -1, -1), (6, -1, -1))
     draw(M)
 
