@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -34,7 +34,7 @@ _topics = ['save']
 _techniques = ['pzf', 'field', 'savePZF', 'loadPZF']
 
 from pyformex.gui.draw import *
-from pyformex.plugins.saveload import *
+from pyformex.saveload import *
 from pyformex.simple import cylinder
 from pyformex.mesh import rectangleWithHole
 from pyformex.examples.Spirals import createSpiral
