@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -24,10 +24,8 @@
 """Seed
 
 Graphical feedback to the creeation of non-uniform seeds.
-
 """
 
-
 _status = 'checked'
 _level = 'normal'
 _topics = ['meshing']
@@ -35,9 +33,7 @@ _techniques = ['seed', 'dialog', 'fslider', 'undraw']
 
 from pyformex.gui.draw import *
 
-
 # globals
-
 base = None
 seed_ticks = None
 x = None
@@ -92,10 +88,10 @@ def do_slider(fld):
 
 def show():
     """Accept data, redraw seeds"""
-    dialog.acceptData()
-    e0 = dialog.results['e0']
-    e1 = dialog.results['e1']
-    redraw(e0, e1)
+    if dialog.validate():
+        e0 = dialog.results['e0']
+        e1 = dialog.results['e1']
+        redraw(e0, e1)
 
 
 def close():
@@ -104,6 +100,7 @@ def close():
         dialog.close()
         dialog = None
     unlockCamera()
+    print("Releasing lock")
     scriptRelease(__file__)
 
 
@@ -131,8 +128,7 @@ def create_dialog():
         default = 'Show',
     )
     # Always install a timeout in official examples!
-    dialog.timeout = timeOut
-    dialog.show()
+    dialog.show(timeoutfunc=timeOut)
     size = dialog.size()
     w, h = size.width(), size.height()
     dialog.resize(2*w, h)
