@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -118,18 +118,20 @@ def drawSuperShape():
 
 
 def acceptData():
-    dialog.acceptData()
-    pf.PF['_SuperShape_data_'] = dialog.results
-    globals().update(dialog.results)
+    if dialog.validate():
+        pf.PF['_SuperShape_data_'] = dialog.results
+        globals().update(dialog.results)
+        return True
+    return False
 
 ##########################
 # Button Functions
 
 def showGrid():
     """Accept data, create and show grid."""
-    acceptData()
-    createGrid()
-    drawGrid()
+    if acceptData():
+        createGrid()
+        drawGrid()
 
 def replayShape():
     """Create and show grid from current data."""
@@ -139,8 +141,8 @@ def replayShape():
 
 def show():
     """Accept data, create and show shape."""
-    acceptData()
-    replayShape()
+    if acceptData():
+        replayShape()
 
 
 def close():
@@ -251,9 +253,6 @@ def createDialog():
     if '_SuperShape_data_' in pf.PF:
         dialog.updateData(pf.PF['_SuperShape_data_'])
 
-    # Always install a timeout in official examples!
-    dialog.timeout = timeOut
-
 
 def run():
     """Show the dialog"""
@@ -265,7 +264,7 @@ def run():
     createDialog()
     setView('eggview', (0., -30., 0.))
     view('eggview')
-    dialog.show()
+    dialog.show(timeoutfunc=timeOut)
     scriptLock(__file__)
 
 if __name__ == '__draw__':
