@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -27,7 +27,6 @@ This example illustrates the creation of spiral curves and the sweeping
 of a plane cross section along thay curve.
 """
 
-
 _status = 'checked'
 _level = 'normal'
 _topics = ['geometry', 'curve', 'mesh']
@@ -79,10 +78,13 @@ dialog_items = [
     _I('spiral3d', 0.0, text='Out of plane factor'),
     _I('spread', False, text='Spread points evenly along spiral'),
     _I('nwires', 1, text='Number of spirals'),
-    _G('sweep', text='Sweep Data', checked=True, items= [
-        _I('cross_section', 'cross', 'select', text='Shape of cross section', choices=cross_sections.keys()),
-        _I('cross_rotate', 0., text='Cross section rotation angle before sweeping'),
-        _I('cross_upvector', '2', text='Cross section vector that keeps its orientation'),
+    _G('sweep', text='Sweep Data', check=True, items= [
+        _I('cross_section', 'cross', choices=listcross_sections.keys(),
+            text='Shape of cross section'),
+        _I('cross_rotate', 0.,
+            text='Cross section rotation angle before sweeping'),
+        _I('cross_upvector', '2',
+            text='Cross section vector that keeps its orientation'),
         _I('cross_scale', 0., text='Cross section scaling factor'),
         ]),
     _I('flyalong', False, text='Fly along the spiral'),
@@ -149,8 +151,9 @@ def createSpiralCurve(turns, nmod):
 
 def show():
     """Accept the data and draw according to them"""
+    if not dialog.validate():
+        return
     clear()
-    dialog.acceptData()
     globals().update(dialog.results)
 
     PL = createSpiralCurve(turns, nmod)
@@ -197,7 +200,7 @@ def close():
 
 
 def timeOut():
-    """What to do on a InputDialog timeout event.
+    """What to do on a Dialog timeout event.
 
     As a policy, all pyFormex examples should behave well on a
     dialog timeout. This is important for developers.
@@ -222,16 +225,13 @@ def createDialog():
     if '_Sweep_data_' in pf.PF:
         dialog.updateData(pf.PF['_Sweep_data_'])
 
-    # Always install a timeout in official examples!
-    dialog.timeout = timeOut
-
 
 def run():
     # Show the dialog and let the user have fun
     linewidth(2)
     clear()
     createDialog()
-    dialog.show()
+    dialog.show(timeoutfunc=timeOut)
     scriptLock(__file__)
 
 if __name__ == '__draw__':
