@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -26,18 +26,18 @@
 
 """
 
-
 _status = 'checked'
 _level = 'normal'
 _topics = ['geometry']
 _techniques = ['programming', 'widgets', 'globals']
 
+
 from pyformex.gui.draw import *
 
 def torus(m, n, surface=True):
     """Create a torus with m cells along big circle and n cells along small."""
     if surface:
-        C = Formex([[[0, 0, 0], [1, 0, 0], [0, 1, 0]], [[1, 0, 0], [1, 1, 0], [0, 1, 0]]], [1, 3])
+        C = Formex('3:016823', [1, 3])
     else:
         C = Formex('l:164', [1, 2, 3])
     F = C.replicm((m, n))
@@ -56,27 +56,29 @@ def series():
 
 def drawTorus(m, n):
     clear()
-    print(m, n)
     draw(torus(m, n), view=None)
 
-def nice():
-    drawTorus(72, 36)
 
+def drawit():
+    global dialog
+    if dialog.validate():
+        drawTorus(**dialog.results)
+
+def close():
+    global dialog
+    dialog.close()
 
 def run():
-    global m, n
+    global dialog
     m = 20
     n = 10
-    while not dialogTimedOut():
-        res = askItems([
-            _I('m', m, itemtype='slider', text='Number of elements along large circle', min=3, max=72),
-            _I('n', n, itemtype='slider', text='Number of elements along small circle', min=3, max=36)
-            ])
-        if not res:
-            break
-
-        globals().update(res)
-        drawTorus(m, n)
+    dialog = Dialog([
+        _I('m', m, itemtype='slider',
+           text='Number of elements along large circle', min=3, max=72),
+        _I('n', n, itemtype='slider',
+           text='Number of elements along small circle', min=3, max=36)
+    ], actions=[('Close', close), ('Draw', drawit)])
+    dialog.show()
 
 
 if __name__ == '__draw__':
