@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -56,6 +56,9 @@ A text in ReST
 
     print(ask("Answer this question with yes or no", ['Yes', 'No']))
 
+
+    print(selectItems(["a", "ccc", "bb", "dddd"], sort=True))
+
 if __name__ == '__draw__':
     run()
 # End
