@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -53,7 +53,7 @@ def run():
     fn = getcfg('datadir') / 'world.jpg'
 
     res = askItems([
-        _I('fn', fn, itemtype='file', pattern='img', exist=True, text=''),
+        _I('fn', fn, itemtype='file', filter='img', exist=True, text=''),
         _I('part', itemtype='radio', choices=["Plane", "Half Sphere", "Full Sphere"], text='Show image on'),
         ])
     if not res:
