@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -406,15 +406,14 @@ def intersectLineWithLine(q1, m1, q2, m2, mode='all', times=False):
 
     """
     if mode == 'all':
-        q1 = np.asarray(q1).reshape(-1, 1, 3)
-        m1 = np.asarray(m1).reshape(-1, 1, 3)
-        q2 = np.asarray(q2).reshape(1, -1, 3)
-        m2 = np.asarray(m2).reshape(1, -1, 3)
+        shape1 = (-1, 1, 3)
+        shape2 = (1, -1, 3)
     else:
-        q1 = np.asarray(q1).reshape(-1, 3)
-        m1 = np.asarray(m1).reshape(-1, 3)
-        q2 = np.asarray(q2).reshape(-1, 3)
-        m2 = np.asarray(m2).reshape(-1, 3)
+        shape1 = shape2 = (-1, 3)
+    q1 = at.checkArray(q1, kind='f', allow='i').reshape(shape1)
+    m1 = at.checkArray(m1, kind='f', allow='i').reshape(shape1)
+    q2 = at.checkArray(q2, kind='f', allow='i').reshape(shape2)
+    m2 = at.checkArray(m2, kind='f', allow='i').reshape(shape2)
 
     dot11 = at.dotpr(m1, m1)
     dot22 = at.dotpr(m2, m2)
@@ -424,7 +423,7 @@ def intersectLineWithLine(q1, m1, q2, m2, mode='all', times=False):
     dot11 = dot11[..., np.newaxis]
     dot22 = dot22[..., np.newaxis]
     dot12 = dot12[..., np.newaxis]
-    with np.errstate(divide='ignore', over='ignore', under='ignore'):
+    with np.errstate(all='ignore'):
         t1 = at.dotpr(q12, m2*dot12-m1*dot22) / denom
         t2 = at.dotpr(q12, m2*dot11-m1*dot12) / denom
         if times:
