@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -272,9 +272,12 @@ class AppMenu(menu.Menu):
     when you created a new script file.
     """
 
-    def __init__(self, title, dir=None, files=None, mode='app', ext=None, recursive=None, max=0, autoplay=False, toplevel=True, parent=None, before=None, runall=True):
+    def __init__(self, title, dir=None, files=None, mode='app', ext=None,
+                 recursive=None, max=0, autoplay=False, toplevel=True,
+                 parent=None, before=None):
         """Create a menu with pyFormex apps/scripts to play."""
-        pf.debug("New AppMenu %s: dir=%s; files=%s" % (title, dir, files), pf.DEBUG.APPS)
+        pf.debug("New AppMenu %s: dir=%s; files=%s" % (title, dir, files),
+                 pf.DEBUG.APPS)
         menu.Menu.__init__(self, title, parent=parent, before=before)
         if dir is None and files is None:
             raise ValueError("At least one of 'dir' or 'files' must be set.")
@@ -300,10 +303,7 @@ class AppMenu(menu.Menu):
             self.pkg = self.dir.name
         else:
             self.pkg = None
-        self.runall = runall
         self.load()
-        #self.addRunAllMenu()
-
 
 
     def loadCatalog(self):
@@ -315,7 +315,9 @@ class AppMenu(menu.Menu):
                     files = col[k]
                 else:
                     files = []
-                mk = AppMenu(k.capitalize(), dir=self.dir, files=files, mode=self.mode, recursive=False, toplevel=False, autoplay=self.autoplay, parent=self, runall=True)
+                mk = AppMenu(k.capitalize(), dir=self.dir, files=files,
+                             mode=self.mode, recursive=False, toplevel=False,
+                             autoplay=self.autoplay, parent=self)
                 for i in cat[k]:
                     if '-' in i:
                         # alpha label like A-B
@@ -324,12 +326,10 @@ class AppMenu(menu.Menu):
                         # string from catalog file
                         lbl = i.capitalize()
                     ki = '%s/%s' % (k, i)
-                    mi = AppMenu(lbl, dir=self.dir, files=col.get(ki, []), mode=self.mode, recursive=False, toplevel=False, autoplay=self.autoplay, parent=mk, runall=self.runall)
-                    ## mi.addRunAllMenu()
-
-                ## mk.addRunAllMenu()
-
-            #self.addRunAllMenu()
+                    mi = AppMenu(lbl, dir=self.dir, files=col.get(ki, []),
+                                 mode=self.mode, recursive=False,
+                                 toplevel=False, autoplay=self.autoplay,
+                                 parent=mk)
             self.files = []
             return True
         return False
@@ -340,7 +340,9 @@ class AppMenu(menu.Menu):
             dirs = self.dir.dirs()
         for d in dirs:
             if d[0] not in '._':  # skip hidden and private dirs
-                m = AppMenu(d, self.dir / d, mode=self.mode, ext=self.ext, autoplay=self.autoplay, recursive=self.recursive, parent=self, runall=self.runall)
+                m = AppMenu(d, self.dir / d, mode=self.mode, ext=self.ext,
+                            autoplay=self.autoplay, recursive=self.recursive,
+                            parent=self)
 
 
     def getFiles(self):
@@ -390,14 +392,6 @@ class AppMenu(menu.Menu):
         self.current = ""
 
 
-    ## def addRunAllMenu(self):
-    ##     if self.runall and pf.cfg['gui/runalloption']:
-    ##         self.insert_sep()
-    ##         self.create_insert_action('Run next app',self.runNextApp)
-    ##         self.create_insert_action('Run all next',self.runAllNext)
-    ##         self.create_insert_action('Run all apps',self.runAllApps)
-
-
     def load(self):
         if self.dir is None:
             self.loadFiles(self.files)
@@ -440,6 +434,20 @@ class AppMenu(menu.Menu):
             return app
 
 
+    def listApps(self, recursive=True):
+        """Returns the full AppNAme of all apps under this menu.
+
+        The default recursive=True includes all apps under submenus as well.
+
+        This is only for app mode menus!
+        """
+        files = [ self.fullAppName(f) for f in self.files]
+        if recursive:
+            for m in self._submenus_:
+                files.extend(m.listApps(recursive=True))
+        return files
+
+
     def run(self, action):
         """Run the selected app.
 
@@ -468,8 +476,9 @@ class AppMenu(menu.Menu):
             script.runAny(appname)
 
 
-    def runAll(self, startfrom='A', stopat='[', count=-1, recursive=True, random=False):
-        """Run all apps with a name in the range [startfrom,stopat].
+    def runAll(self, startfrom='A', stopat='[', count=-1, recursive=True,
+               timeout=1.0, pause=1.0, random=False):
+        """Run all apps with a name in the range [startfrom,stopat[.
 
         Runs the apps with a name >= `startfrom` and < `stopat`.
         The default will run all apps starting with a capital (like
@@ -509,7 +518,7 @@ class AppMenu(menu.Menu):
             pf.GUI.runallmode = True
             save = widgets.input_timeout
             pf.GUI.drawlock.free()
-            widgets.input_timeout = 1.0
+            widgets.input_timeout = timeout
             tcount = 0
             try:
                 for f in files:
@@ -519,10 +528,10 @@ class AppMenu(menu.Menu):
                     print("Running app '%s'" % f)
                     self.runApp(f)
                     script.breakpt(msg="Breakpoint from runall")
-                    sleep(1)  # ,msg="EXITREQUESTED: %s" % script.exitrequested)
                     if script.exitrequested:
                         break
                     tcount += 1
+                    sleep(pause)
             finally:
                 widgets.input_timeout = save
                 pf.GUI.drawlock.allow()
@@ -532,7 +541,8 @@ class AppMenu(menu.Menu):
         # if room for more, recurse into submenus
         if recursive and (count < 0 or tcount < count):
             for m in self._submenus_:
-                n = m.runAll(startfrom, stopat, count=count-tcount, recursive=recursive, random=random)
+                n = m.runAll(startfrom, stopat, count=count-tcount,
+                             recursive=recursive, random=random)
                 tcount += n
                 if count > 0 and tcount >= count:
                     print("Ran %s examples; getting out" % tcount)
@@ -544,54 +554,6 @@ class AppMenu(menu.Menu):
         return tcount
 
 
-    def runAllNext(self, offset=1, count=-1):
-        """Run a sequence of apps, starting with the current plus offset.
-
-        If a positive count is specified, at most count scripts
-        will be run.
-        A nonzero offset may be specified to not start with the current
-        script.
-        """
-        try:
-            i = self.files.index(self.current) + offset
-        except ValueError:
-            i = 0
-        self.runAll(first=i, count=count)
-
-
-    def runCurrent(self):
-        """Run the current app, or the first if none was played yet."""
-        self.runAllNext(offset=0, count=1)
-
-
-    def runNextApp(self):
-        """Run the next app, or the first if none was played yet."""
-        self.runAllNext(offset=1, count=1)
-
-
-    def runRandom(self):
-        """Run a random script."""
-        i = random.randint(0, len(self.files)-1)
-        self.runAll(first=i, count=1)
-
-
-    def runAllApps(self):
-        from pyformex.gui import draw
-        res = draw.askItems([
-            ('timeout', True),
-            ('random', False),
-            ('recursive', True),
-            ('count', -1),
-            ])
-        if not res:
-            return
-        from pyformex.gui.toolbar import timeout
-        timeout(res['timeout'])
-        del res['timeout']
-        self.runAll(**res)
-        timeout(False)
-        print("Finished running all examples")
-
 
     def reload(self):
         """Reload the scripts from dir.
@@ -699,7 +661,7 @@ def createAppMenu(mode='app', parent=None, before=None):
         appdirs = pf.cfg['scriptdirs']
 
 
-    history = AppMenu('History', files=pf.cfg['gui/%shistory'%mode], max=pf.cfg['gui/history_max'], mode=mode, parent=appmenu, runall=False)
+    history = AppMenu('History', files=pf.cfg['gui/%shistory'%mode], max=pf.cfg['gui/history_max'], mode=mode, parent=appmenu)
 
     # Fill in missing default locations : this enables the user
     # to keep the pyFormex installed examples in his config
@@ -708,7 +670,7 @@ def createAppMenu(mode='app', parent=None, before=None):
     appdirs = [d for d in appdirs if d[1].exists() and d[1].is_dir()]
     for name, path in appdirs:
         pf.debug("Loading menu %s from %s" % (name, path), pf.DEBUG.MENU)
-        m = AppMenu(name, path, mode=mode, autoplay=True, parent=appmenu, runall=True)
+        m = AppMenu(name, path, mode=mode, autoplay=True, parent=appmenu)
 
     setattr(pf.GUI, '%shistory'%mode, history)
 
