@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -47,11 +47,7 @@ from pyformex.gui import drawlock
 from pyformex.opengl import colors, actors, decors
 
 # Extra things that we want in the scripting language
-Dialog = widgets.InputDialog
-_I = widgets.simpleInputItem
-_G = widgets.groupInputItem
-_H = widgets.hboxInputItem
-_T = widgets.tabInputItem
+from pyformex.gui.widgets import Dialog, _I, _G, _C, _T
 from pyformex.script import *
 from pyformex.lazy import *
 from pyformex.opengl.colors import *
@@ -95,7 +91,7 @@ def closeGui():
 def closeDialog(name):
     """Close the named dialog.
 
-    Closes the InputDialog with the given name. If multiple dialogs are
+    Closes the Dialog with the given name. If multiple dialogs are
     open with the same name, all these dialogs are closed.
 
     This only works for dialogs owned by the pyFormex GUI.
@@ -117,15 +113,6 @@ def showMessage(text, actions=['OK'], level='info', modal=True, align='00', **ka
         w.move(100, 100)
     if modal:
         return w.getResults()
-    # else:
-    #     w.show()
-    #     while not w.result() == 3:
-    #         print(w.result())
-    #         pf.app.processEvents()
-    #         sleep(1)
-    #     print(w.result())
-    #     w.accept()
-    #     return 'exit'
 
 
 def showInfo(text, actions=['OK'], modal=True):
@@ -155,7 +142,8 @@ def ack(question, **kargs):
     return ask(question, ['Yes', 'No'], **kargs) == 'Yes'
 
 
-def showText(text, itemtype='text', actions=[('OK', None)], modal=True, mono=False):
+def showText(text, itemtype='text', actions=[('OK',)], modal=True,
+             mono=False):
     """Display a text in a dialog window.
 
     Creates a dialog window displaying some text. The dialog can be modal
@@ -343,7 +331,7 @@ def editFile(fn, exist=False):
 _dialog_widget = None
 _dialog_result = None
 
-def askItems(items, timeout=None, **kargs):
+def askItems(items, *, timeout=None, modal=True, **kargs):
     """Ask the value of some items to the user.
 
     Create an interactive widget to let the user set the value of some items.
@@ -357,14 +345,14 @@ def askItems(items, timeout=None, **kargs):
     A tuple (key,value) will be transformed to a dict
     {'key':key, 'value':value}.
 
-    See the widgets.InputDialog class for complete description of the
+    See the widgets.Dialog class for complete description of the
     available input items.
 
     A timeout (in seconds) can be specified to have the input dialog
     interrupted automatically and return the default values.
 
     The remaining arguments are keyword arguments that are passed to the
-    widgets.InputDialog.getResult method.
+    widgets.Dialog.getResult method.
 
     Returns a dictionary with the results: for each input item there is a
     (key,value) pair. Returns an empty dictionary if the dialog was canceled.
@@ -372,13 +360,13 @@ def askItems(items, timeout=None, **kargs):
     """
     global _dialog_widget, _dialog_result
 
-    w = widgets.InputDialog(items, **kargs)
-
+    w = widgets.Dialog(items, **kargs)
     _dialog_widget = w
     _dialog_result = None
-    res = w.getResults(timeout)
+    res = w.getResults(modal=modal, timeout=timeout)
     _dialog_widget = None
-    _dialog_result = w.result()
+    # The dialog result is currently not available
+    #_dialog_result = w.closure
     return res
 
 
@@ -391,17 +379,40 @@ def currentDialog():
     """
     return _dialog_widget
 
-def dialogAccepted():
-    """Returns True if the last askItems() dialog was accepted."""
-    return _dialog_result == widgets.ACCEPTED
+# def dialogAccepted():
+#     """Returns True if the last askItems() dialog was accepted."""
+#     return _dialog_result == widgets.ACCEPTED
 
-def dialogRejected():
-    """Returns True if the last askItems() dialog was rejected."""
-    return _dialog_result == widgets.REJECTED
+# def dialogRejected():
+#     """Returns True if the last askItems() dialog was rejected."""
+#     return _dialog_result == widgets.REJECTED
 
-def dialogTimedOut():
-    """Returns True if the last askItems() dialog timed out."""
-    return _dialog_result == widgets.TIMEOUT
+# def dialogTimedOut():
+#     """Returns True if the last askItems() dialog timed out."""
+#     return _dialog_result == widgets.TIMEOUT
+
+
+def selectItems(choices, caption='Select from list', default=[], single=False,
+                check=False, sort=False, **kargs):
+     """Ask the user to select one or more items from a list.
+
+     This is a convenience function presenting a dialog with a single
+     input item: an InputList. It allows the user to select one or more items
+     from a list.
+
+     Returns
+     -------
+     list
+         A list with the selected items
+     """
+     res = askItems([
+         _I(name='input', value=default, itemtype='list', choices=choices,
+            text='', single=single, check=check, sort=sort, **kargs),
+     ], caption=caption)
+     res = res['input'] if res else []
+     if sort:
+         res.sort()
+     return res
 
 
 def askFile(cur=None, filter='all', exist=True, multi=False, compr=False,
@@ -986,7 +997,8 @@ def flyAlong(path, upvector=[0., 1., 0.], sleeptime=None):
         wait()
         pf.canvas.display()
         pf.canvas.update()
-        image.saveNext()
+        if image.autoSaveOn():
+            image.saveNext()
 
     delay(saved)
     pf.GUI.enableButtons(pf.GUI.actions, ['Continue'], saved1)
@@ -1128,21 +1140,21 @@ def pick(mode='actor', filter=None, oneshot=False, func=None, pickable=None, pro
 
     subsel_values = {'any': 'any vertex', 'all': 'all vertices'}
 
-    def _set_selection_filter(s):
+    def _set_selection_filter(item):
         """Set the selection filter mode
 
         This function is used to change the selection filter from the
         selection InputCombo widget.
         s is one of the strings in selection_filters.
         """
-        s = str(s)
+        s = item.value()
         if pf.canvas.pick_mode is not None and s in pf.canvas.selection_filters:
             pf.canvas.start_selection(None, s)
 
 
-    def _set_subsel_mode(val):
+    def _set_subsel_mode(item):
         """Toggle the value of the subsel mode"""
-        pf.canvas.pick_mode_subsel = str(val)[:3]
+        pf.canvas.pick_mode_subsel = item.value()[:3]
 
 
     if pf.canvas.pick_mode is not None:
@@ -1150,23 +1162,28 @@ def pick(mode='actor', filter=None, oneshot=False, func=None, pickable=None, pro
         return
 
     if mode not in pf.canvas.getPickModes():
-        warning("Invalid picking mode: %s. Expected one of %s." % (mode, pf.canvas.getPickModes()))
+        warning("Invalid picking mode: %s. Expected one of %s." % (
+            mode, pf.canvas.getPickModes()))
         return
 
-    pick_buttons = widgets.ButtonBox('Selection:', [('Cancel', pf.canvas.cancel_selection), ('OK', pf.canvas.accept_selection)])
+    pick_buttons = widgets.ButtonBox('Selection:', [
+        ('Cancel', pf.canvas.cancel_selection),
+        ('OK', pf.canvas.accept_selection)])
 
     if mode == 'element':
         filters = pf.canvas.selection_filters
     else:
         filters = pf.canvas.selection_filters[:3]
-    filter_combo = widgets.InputCombo('Filter:', None, choices=filters, onselect=_set_selection_filter)
+    filter_combo = widgets.InputCombo(
+        'Filter:', None, choices=filters, func=_set_selection_filter)
     if filter is not None and filter in pf.canvas.selection_filters:
         filter_combo.setValue(filter)
 
     if mode in ['actor', 'element', 'face', 'edge']:
         txt = subsel_values[pf.canvas.pick_mode_subsel]
-        #subsel_button = widgets.ButtonBox('Pick by ', [(txt, _toggle_subsel_mode), ])
-        subsel_button = widgets.InputCombo('Pick by ', txt, choices=list(subsel_values.values()), onselect=_set_subsel_mode)
+        subsel_button = widgets.InputCombo(
+            'Pick by ', txt, choices=list(subsel_values.values()),
+            func=_set_subsel_mode)
     else:
         subsel_button = None
 
@@ -1260,14 +1277,6 @@ def pickFocus():
 LineDrawing = None
 edit_modes = ['undo', 'clear', 'close']
 
-
-def set_edit_mode(s):
-    """Set the drawing edit mode."""
-    s = str(s)
-    if s in edit_modes:
-        pf.canvas.edit_drawing(s)
-
-
 def drawLinesInter(mode ='line', single=False, func=None):
     """Enter interactive drawing mode and return the line drawing.
 
@@ -1275,17 +1284,28 @@ def drawLinesInter(mode ='line', single=False, func=None):
     This function differs in that it provides default displaying
     during the drawing operation and a button to stop the drawing operation.
 
-    The drawing can be edited using the methods 'undo', 'clear' and 'close', which
-    are presented in a combobox.
+    The drawing can be edited using the methods 'undo', 'clear' and 'close',
+    which are presented in a combobox.
     """
+    def _set_edit_mode(item):
+        """Set the drawing edit mode."""
+        s = item.value()
+        if s in edit_modes:
+            pf.canvas.edit_drawing(s)
+        if pf.canvas.drawing_mode is not None:
+            warning("You need to finish the previous drawing operation first!")
+
     if pf.canvas.drawing_mode is not None:
         warning("You need to finish the previous drawing operation first!")
         return
     if func is None:
         func = showLineDrawing
-    drawing_buttons = widgets.ButtonBox('Drawing:', [('Cancel', pf.canvas.cancel_drawing), ('OK', pf.canvas.accept_drawing)])
+    drawing_buttons = widgets.ButtonBox('Drawing:', [
+        ('Cancel', pf.canvas.cancel_drawing),
+        ('OK', pf.canvas.accept_drawing)])
     pf.GUI.statusbar.addWidget(drawing_buttons)
-    edit_combo = widgets.InputCombo('Edit:', None, choices=edit_modes, onselect=set_edit_mode)
+    edit_combo = widgets.InputCombo(
+        'Edit:', None, choices=edit_modes, func=_set_edit_mode)
     pf.GUI.statusbar.addWidget(edit_combo)
     lines = pf.canvas.drawLinesInter(mode, single, func)
     pf.GUI.statusbar.removeWidget(drawing_buttons)
@@ -2779,9 +2799,9 @@ def shrink(onoff, factor=None):
 
 
 ###########################################################################
-# Make _I, _G, _H, _T be included when doing 'from gui.draw import *'
+# Make _I, _G, _C, _T be included when doing 'from gui.draw import *'
 #
 
-__all__ = [n for n in list(globals().keys()) if not n.startswith('_')] + ['_I', '_G', '_H', '_T']
+__all__ = [n for n in list(globals().keys()) if not n.startswith('_')] + ['_I', '_G', '_C', '_T']
 
 ## End
