@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -322,24 +322,25 @@ class Gui(QtWidgets.QMainWindow):
         on top, and a statusbar at the bottom.
         """
         pf.debug('Creating Main Window', pf.DEBUG.GUI)
-        self.on_exit = []
+        self.on_exit = set()
         QtWidgets.QMainWindow.__init__(self)
         self.fullscreen = False
         self.setWindowTitle(windowname)
         # add widgets to the main window
 
-
         # The status bar
         pf.debug('Creating Status Bar', pf.DEBUG.GUI)
         self.statusbar = self.statusBar()
-        #self.statusbar.setSizePolicy(QtWidgets.QSizePolicy.Minimum,QtWidgets.QSizePolicy.Minimum)
-        #self.statusbar.setFixedHeight(32)
-        #self.statusbar.setContentsMargins(0,0,0,0)
-        #widgets.addEffect(self.statusbar,color=(255,0,0))
-        from pyformex.gui.menus import File
-        self.curproj = widgets.ButtonBox('Project:', [('None', File.openExistingProject)])
-        self.curfile = widgets.ButtonBox('', [('Script:', toggleAppScript), ('None', File.openScript)])
-        self.curdir = widgets.ButtonBox('Cwd:', [('None', draw.askDirname)])
+        # self._statusbar_funcs = {}
+
+        self.curproj = self.addStatusbarButtons(
+            'Project:', actions=[('None', File.openExistingProject)])
+        self.curfile = self.addStatusbarButtons(
+            '', actions=[('Script:', toggleAppScript),
+                         ('None', File.openScript)])
+        self.curdir = self.addStatusbarButtons(
+            'Cwd:', actions=[('None', draw.askDirname)])
+
         self.canPlay = False
         self.canEdit = False
 
@@ -516,15 +517,27 @@ class Gui(QtWidgets.QMainWindow):
 
         self.filewatch = FileWatcher()
 
-
         # Set up hot keys: hitting the key will emit the corresponding signal
         self.hotkey  = {
             QtCore.Qt.Key_F2: self.signals.SAVE,
-#            QtCore.Qt.Key_F5: self.signals.FULLSCREEN,
             QtCore.Qt.Key_F11: self.signals.FULLSCREEN,
             }
 
 
+    def addStatusbarButtons(self, name, actions, **kargs):
+        """Install a group of buttons in the statusbar"""
+        w = widgets.ButtonBox(name=name, actions=actions,
+                              parent=self.statusbar, spacer='', **kargs)
+        self.addStatusbarWidget(w)
+        return w
+
+
+    def addStatusbarWidget(self, w):
+        self.statusbar.addWidget(w)
+        r = self.statusbar.childrenRect()
+        self.statusbar.setFixedHeight(r.height()+6)
+
+
     def createConsole(self, config):
         """Create the message board and console
 
@@ -703,13 +716,6 @@ class Gui(QtWidgets.QMainWindow):
         return toolbar
 
 
-    def addStatusBarButtons(self):
-        self.statusbar.addWidget(self.curproj)
-        self.statusbar.addWidget(self.curfile)
-        self.statusbar.addWidget(self.curdir)
-        r = self.statusbar.childrenRect()
-        self.statusbar.setFixedHeight(r.height()+4)
-
 
     def addInputBox(self):
         self.input = widgets.InputString('Input:', '')
@@ -870,7 +876,7 @@ class Gui(QtWidgets.QMainWindow):
         This substitute function will find the correct position from
         the xwininfo command output.
         """
-        res = xwininfo(self.winId())
+        res = xwininfo(windowid=self.winId())
         ax, ay, rx, ry = [int(res[key]) for key in [
             'Absolute upper-left X', 'Absolute upper-left Y',
             'Relative upper-left X', 'Relative upper-left Y',
@@ -878,16 +884,26 @@ class Gui(QtWidgets.QMainWindow):
         return ax-rx, ay-ry
 
 
-    def XGeometry(self):
-        """Get the main window position and size from the xwininfo command.
+    def XGeometry(self, border=True):
+        """Get the main window position and size.
 
+        Parameters
+        ----------
+        border: bool
+            If True (default), the returned geometry includes the
+            border frame. If set to False, the border is excluded.
+
+        Returns
+        -------
+        tuple (x,y,w,h)
+            A tuple of int with the top left position and the size
+            of the window geometry.
         """
-        res = xwininfo(self.winId())
-        x, y, w, h = [int(res[key]) for key in [
-            'Absolute upper-left X', 'Absolute upper-left Y',
-            'Width', 'Height',
-            ]]
-        return x, y, w, h
+        if border:
+            geom = self.frameGeometry()
+        else:
+            geom = self.geometry()
+        return geom.getRect()
 
 
     def writeSettings(self):
@@ -919,17 +935,17 @@ class Gui(QtWidgets.QMainWindow):
 
 
     def findDialog(self, name):
-        """Find the InputDialog with the specified name.
+        """Find the Dialog with the specified name.
 
-        Returns the list with maching dialogs, possibly empty.
+        Returns the list with matching dialogs, possibly empty.
         """
-        return self.findChildren(widgets.InputDialog, str(name))
+        return self.findChildren(widgets.Dialog, str(name))
 
 
     def closeDialog(self, name):
-        """Close the InputDialog with the specified name.
+        """Close the Dialog with the specified name.
 
-        Closest all the InputDialogs with the specified caption
+        Closest all the Dialogs with the specified caption
         owned by the GUI.
         """
         for w in self.findDialog(name):
@@ -1007,8 +1023,17 @@ class Gui(QtWidgets.QMainWindow):
 
 
     def onExit(self, func):
-        """Register a function for execution on exit"""
-        self.on_exit.append(func)
+        """Register a function for execution on exit of the GUI.
+
+        Parameters
+        ----------
+        func: callable
+            A function to be called on exit of the GUI. There is
+            no guaranteed order of execution of the exit functions.
+        """
+        if not callable(func):
+            raise ValueError('func should be a callable')
+        self.on_exit.add(func)
 
 
     def closeEvent(self, event):
@@ -1030,6 +1055,12 @@ class Gui(QtWidgets.QMainWindow):
             script.force_finish()
         if exitDialog():
             self.drawlock.free()
+            pf.debug("Executing registered exit functions", pf.DEBUG.GUI)
+            for f in self.on_exit:
+                pf.debug(f, pf.DEBUG.GUI)
+                f()
+            self.writeSettings()
+            # allow user to see result before shutting down
             dooze = pf.cfg['gui/dooze']
             if dooze > 0:
                 print("Exiting in %s seconds" % dooze)
@@ -1039,11 +1070,6 @@ class Gui(QtWidgets.QMainWindow):
             sys.stdout.flush()
             sys.stderr = sys.__stderr__
             sys.stdout = sys.__stdout__
-            pf.debug("Executing registered exit functions", pf.DEBUG.GUI)
-            for f in self.on_exit:
-                pf.debug(f, pf.DEBUG.GUI)
-                f()
-            self.writeSettings()
             event.accept()
         else:
             event.ignore()
@@ -1133,10 +1159,37 @@ def exitDialog():
     return True
 
 
-def xwininfo(windowid=None, name=None):
-    """Returns the X window info parsed as a dict.
+def xwininfo(*, windowid=None, name=None):
+    """Get information about an X window.
 
-    Either the windowid or the window name has to be specified.
+    Returns the information about an X11 window as obtained from
+    the ``xwininfo`` command, but parsed as a dict. The window can
+    be specified by its id or by its name. If neither is provided,
+    the user needs to interactively select a window by clicking the
+    mouse in that window.
+
+    Parameters
+    ----------
+    windowid: str, optional
+        A hex string with the window id.
+    name: str
+        The window name, usually displayed in the top border decoration.
+    check_only: bool
+        If True, only check whether the window exists, but do not return
+        the info.
+
+    Returns
+    -------
+    dict
+        Return all the information obtained from calling
+        ``xwininfo`` for the specified or picked window.
+        If a window id or name is specified that does not exist,
+        an empty dict is returned.
+
+    Notes
+    -----
+    The window id of the pyFormex main window can be obtained from
+    pf.GUI.winId(). The name of the window is pf.Version().
     """
     cmd = 'xwininfo %s'
     if windowid is not None:
@@ -1191,17 +1244,6 @@ def pidofxwin(windowid):
     return None
 
 
-def windowExists(windowname):
-    """Check if a GUI window with the given name exists.
-
-    On X-Window systems, we can use the xwininfo command to find out whether
-    a window with the specified name exists.
-    """
-    P = process.run('xwininfo -name "%s" > /dev/null 2>&1' % windowname,
-                     shell=True)
-    return P.returncode == 0
-
-
 def findOldProcesses(max=16):
     """Find old pyFormex GUI processes still running.
 
@@ -1532,7 +1574,7 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
     # cleanup
     if splash is not None:
         splash.showMessage("Set status bar");
-    pf.GUI.addStatusBarButtons()
+    #pf.GUI.addStatusBarButtons()
 
     pf.debug("Showing the GUI", pf.DEBUG.GUI)
     if splash is not None:
