@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -486,7 +486,7 @@ class ActionList(object):
 
     def removeAll(self):
         """Remove all actions from self"""
-        for name in self.actions:
+        for name in self.names():
             self.remove(name)
 
 
