@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -45,10 +45,9 @@ from collections import OrderedDict
 # functions have already been defined here.
 
 def printwindow():
-    pf.app.syncX()
-    r = pf.GUI.frameGeometry()
-    print("Qt geom(w,h,x,y): %s,%s,%s,%s" % (r.width(), r.height(), r.x(), r.y()))
-    print("According to xwininfo, (x,y) is %s,%s" % pf.GUI.XPos())
+    #pf.app.syncX()
+    r = pf.GUI.XGeometry()
+    print(f"Qt geom(w,h,x,y): {r}")
 
 
 _geometry=None
@@ -60,9 +59,9 @@ def saveGeometry():
 def restoreGeometry():
     pf.GUI.restoreGeometry(_geometry)
 
-
-def moveCorrect():
-    pf.GUI.move(*pf.GUI.XPos())
+# This is unneeded as the Qt bug has been resolve
+# def moveCorrect():
+#     pf.GUI.move(*pf.GUI.XPos())
 
 def closeLogFile():
     if draw.logfile:
@@ -113,7 +112,6 @@ MenuData = (_('&Actions'), [
     (_('&Stop'), draw.raiseExit),
     ("---", None),
     (_('&App Info'), draw.showDoc),
-    ## (_('&Run All Examples'),runAllExamples),
     ("---", None),
     ## (_('&Reset Picking Mode'),resetPick),
     (_('&Reset GUI'), draw.resetGUI),
@@ -132,7 +130,7 @@ MenuData = (_('&Actions'), [
     (_('&Print Bbox'), draw.printbbox),
     (_('&Print Viewport Settings'), draw.printviewportsettings),
     (_('&Print Window Geometry'), printwindow),
-    (_('&Correct the Qt Geometry'), moveCorrect),
+    # (_('&Correct the Qt Geometry'), moveCorrect),
     (_('&Save Geometry'), saveGeometry),
     (_('&Restore Geometry'), restoreGeometry),
     (_('&Toggle Input Timeout'), toolbar.timeout),
