@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -33,7 +33,7 @@ from pyformex import utils
 from pyformex import project
 
 from .Settings import updateSettings
-from .. import widgets, draw, image
+from .. import widgets, dialogs, draw, image
 from ..draw import _I, _G, busyCursor
 
 
@@ -452,33 +452,29 @@ def saveImage(multi=False):
 
     This will show the Save Image dialog, with the multisave mode checked if
     multi = True. Then, depending on the user's selection, it will either:
+
      - save the current Canvas/Window to file
      - start the multisave/autosave mode
      - do nothing
     """
-    dia = widgets.SaveImageDialog(pf.cfg['workdir'], ['img', 'icon', 'all'], multi=multi)
-    opt = dia.getResults()
-    if opt:
-        opt.fn = Path(opt.fn)
-        if opt.fm == 'From Extension':
-            if opt.fn.suffix == '':
-                opt.fn = opt.fn.with_suffix('.png')
-            opt.fm = None
-        if opt.qu < 0:
-            opt.qu = -1
-        updateSettings({'workdir': Path(opt.fn).parent}, save=True)
-        image.save(filename=opt.fn,
-                   format=opt.fm,
-                   quality=opt.qu,
-                   size=opt.sz,
-                   window=opt.wi,
-                   multi=opt.mu,
-                   hotkey=opt.hk,
-                   autosave=opt.au,
-                   border=opt.bo,
-                   grab=opt.gr,
-                   alpha=opt.al
-                   )
+    dia = dialogs.SaveImageDialog(pf.cfg['workdir'], ['img', 'icon', 'all'],
+                                  multi=multi)
+    res = dia.getResults()
+    if res:
+        del res['set_size']
+        pf.debug(res, pf.DEBUG.IMAGE)
+        # updateSettings({'workdir': Path(opt.fn).parent}, save=True)
+        image.saveImage(**res)
+
+
+def startMultiSave():
+    """Start/change multisave mode."""
+    saveImage(True)
+
+
+def stopMultiSave():
+    """Stop multisave mode."""
+    image.saveImage()
 
 
 def saveIcon():
@@ -492,16 +488,6 @@ def saveIcon():
     if fn:
         image.saveIcon(fn, size=32)
 
-
-def startMultiSave():
-    """Start/change multisave mode."""
-    saveImage(True)
-
-
-def stopMultiSave():
-    """Stop multisave mode."""
-    image.save()
-
 viewer = None
 def showImage():
     """Display an image file."""
@@ -526,7 +512,7 @@ def createMovieInteractive():
         pf.warning('You need to start multisave mode first!')
         return
 
-    names = image.multisave[0]
+    names = image.multisave['filename']
     glob = names.glob()
 
     res = draw.askItems(
@@ -624,49 +610,19 @@ def showWebGL():
         draw.showHTML(last_exported_webgl)
 
 
-_recording_pid = 0
-
-def recordSession(stop=0):
+def recordSession():
     """Record the current pyFormex session."""
-    global _recording_pid
-    from pyformex.gui.guimain import hasDRI
-
-    print("RECORDING with dri=%s" % pf.options.dri)
-
-    ok = utils.External.has('recordmydesktop')
-    if not ok:
-        return
-    if hasDRI():
-        if not draw.ack("Recording the session while using DRI may fail to correctly capture the OpenGL canvas. We recommend starting pyformex with the --nodri option to do session recording (at the expense of a slower execution). If you click YES I will nevertheless go ahead with recording."):
-            return
-
-    fn = draw.askFilename(pf.cfg['workdir'], "Theora video files (*.ogv)", exist=False)
-    if not fn:
+    pf.debug("RECORDING with dri=%s" % pf.options.dri, pf.DEBUG.IMAGE)
+    utils.External.require('ffmpeg')
+    dia =  dialogs.RecordSessionDialog(pf.cfg['workdir'])
+    res = dia.getResults()
+    if not res:
         return
 
-    print("Recording your session to file %s" % fn)
-    x, y, w, h = pf.GUI.XGeometry()
-    cmd = "recordmydesktop -x %s -y %s --width %s --height %s --no-frame -o %s" % (x, y, w, h, fn)
-    P = utils.system(cmd, wait=False, verbose=True)
-    print("Recording pid = %s" % P.pid)
-    #
-    # TODO: this should be replaced with storing the process P
-    #
-    _recording_pid = P.pid
-
-
-def stopRecording(stop=15):
-    global _recording_pid
-    print("STOP RECORDING")
-    if _recording_pid:
-        # Was recording: finish it
-        utils.killProcesses([_recording_pid], stop)
-        # should check that it has stopped
-        _recording_pid = 0
-
-
-def abortRecording():
-    stopRecording(6)
+    #TODO: ask to overwrite it?, and delete it
+    #if fn.exists():
+    #    pass
+    image.recordSession(**res)
 
 
 MenuData = (_('&File'), [
@@ -708,11 +664,7 @@ MenuData = (_('&File'), [
     (_('&Export as multiscene WebGL'), multiWebGL),
     (_('&Show exported WebGL'), showWebGL),
     (_('&Show HTML'), draw.showHTML),
-    (_('&Record Session'), [
-        (_('&Start Recording'), recordSession),
-        (_('&Stop Recording'), stopRecording),
-        (_('&Abort Recording'), abortRecording),
-        ]),
+    (_('&Record Session'), recordSession),
     (_('---2'), None),
     (_('E&xit'), draw.closeGui),
     ])
