@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -33,7 +33,7 @@ from pyformex import gui
 from pyformex import plugins
 from pyformex.gui import widgets, toolbar, draw
 from pyformex.cmdtools import savePreferences
-from pyformex.gui.draw import _I, _G, _H, _T
+from pyformex.gui.draw import _I, _G, _C, _T
 
 
 def updateSettings(res, save=None):
@@ -86,19 +86,12 @@ def updateSettings(res, save=None):
     # the GUI is created
     if pf.GUI:
         for f in todo:
-            print("NOW DOING %s" % f)
             try:
-                print(f.__name__)
-                if f.__name__ == 'updateStyl':
-                    print("NOT DOING %s" % f)
-                else:
-                    print("HERE WE GO WITH %s" % f)
-                    f()
+                f()
             except Exception as e:
                 print('!' * 72)
-                print("Got an exception why updating settings with %s" % f)
+                print("Got an exception while updating settings with %s" % f)
                 print(e)
-            print("NOW DONE")
 
     pf.debug("\nNEW SETTINGS\n%s"%pf.cfg, pf.DEBUG.CONFIG)
     pf.debug("\nNEW PREFERENCES\n%s"%pf.prefcfg, pf.DEBUG.CONFIG)
@@ -123,8 +116,11 @@ def settings():
         dia.close()
 
     def accept(save=False):
-        dia.acceptData()
+        if not dia.validate():
+            print("Invalid data! Changes not accepted!")
+            return
         res = dia.results
+        dia.close()
         res['_save_'] = save
         ok_plugins = utils.subDict(res, '_plugins/')
         res['gui/console'] = utils.inverseDict(gui_console_options)[res['gui/console']]
@@ -154,41 +150,105 @@ def settings():
         changeDirs('appdirs')
 
     enablers = []
-    mouse_settings = autoSettings(['gui/rotfactor', 'gui/panfactor', 'gui/zoomfactor', 'gui/autozoomfactor', 'gui/dynazoom', 'gui/wheelzoom', 'gui/wheelzoomfactor'])
 
     # Use _ to avoid adding these items in the config
     plugin_items = [_I('_plugins/'+name, name in pf.cfg['gui/plugins'], text=text) for name, text in plugins.pluginMenus()]
 
-    bindings_choices = ('any',) + gui.BINDINGS
-    bindings_current = pf.cfg['gui/bindings'].lower()
-
-    appearance = [
-        _I('gui/style', pf.app.currentStyle(), choices=pf.app.getStyles()),
-        _I('gui/font', pf.app.font().toString(), 'font'),
-        # _I('gui/fontfamily', pf.app.font().family()),
-        # _I('gui/fontsize', pf.app.font().pointSize()),
-        ]
-
-    toolbartip = "Currently, changing the toolbar position will only be in effect when you restart pyFormex"
-    toolbars = [
-        _I('gui/%s'%t, pf.cfg['gui/%s'%t], text=getattr(pf.GUI, t).windowTitle(), choices=['left', 'right', 'top', 'bottom'], itemtype='radio', tooltip=toolbartip) for t in ['camerabar', 'modebar', 'viewbar']
-        ]
-    # Use _ to avoid adding these items in the config
-    actionbuttons = [
-        _I('_gui/%sbutton'%t, t in pf.cfg['gui/actionbuttons'], text="%s Button" % t.capitalize()) for t in _actionbuttons
-        ]
+    ##### GENERAL settings #####
+    general_settings = [
+        _I('syspath', tooltip="If you need to import modules from a non-standard path, you can supply additional paths to search here."),
+        _I('editor', tooltip="The command to be used to edit a script file. The command will be executed with the path to the script file as argument."),
+        _I('viewer', tooltip="The command to be used to view an HTML file. The command will be executed with the path to the HTML file as argument."),
+        _I('browser', tooltip="The command to be used to browse the internet. The command will be executed with an URL as argument."),
+        _I('help/docs'),
+        _I('autorun', text='Startup script', tooltip='This script will automatically be run at pyFormex startup'),
+        _I('scriptdirs', text='Script Paths', tooltip='pyFormex will look for scripts in these directories', buttons=[('Edit', changeScriptDirs)]),
+        _I('appdirs', text='Applicationt Paths', tooltip='pyFormex will look for applications in these directories', buttons=[('Edit', changeAppDirs)]),
+        _I('autoglobals', text='Auto Globals', tooltip='If checked, global Application variables of any Geometry type will automatically be copied to the pyFormex global variable dictionary (PF), and thus become available in the GUI'),
+        _I('showapploaderrors', text='Show Application Load Error Traceback', tooltip='If checked, a traceback of exceptions occurring at Application Load time will be output. If unchecked, such exceptions will be suppressed, and the application will not run.'),
+        _I('openlastproj', text="Reload last project on startup"),
+        _I('check_print', text="Check scripts for the use of the print statement"),
+        _I('plot2d', text="Prefered 2D plot library", choices=['matplotlib', 'gnuplot']),
+    ]
 
+    ##### STARTUP settings #####
     # Make sure splash image exists
     cur = pf.cfg['gui/splash']
     if not cur.exists():
         pf.cfg['gui/splash'] = cur = pf.refcfg['gui/splash']
     splashviewer = widgets.ImageView(cur, maxheight=200)
-
-    mail_settings = [
-        _I('mail/sender', pf.cfg['mail/sender'], text="My mail address"),
-        _I('mail/server', pf.cfg['mail/server'], text="Outgoing mail server")
+    bindings_choices = ('any',) + gui.BINDINGS
+    bindings_current = pf.cfg['gui/bindings'].lower()
+    startup_settings = [
+        _I('_info_01_', 'The settings on this page will only become active after restarting pyFormex', itemtype='info'),
+        _I('gui/bindings', bindings_current, choices=bindings_choices, tooltip="The Python bindings for the Qt libraries"),
+        #_I('gui/interpreter',interpreter_current,choices=interpreter_choices,tooltip="The Python interpreter to use for the message board"),
+        _I('gui/splash', text='Splash image', itemtype='filename', filter='img', exist=True, preview=splashviewer),
+        splashviewer,
+    ]
+    ##### GUI settings #####
+    gui_appearance = [
+        _I('gui/style', pf.app.currentStyle(), choices=pf.app.getStyles()),
+        _I('gui/font', pf.app.font().toString(), 'font'),
+        # _I('gui/fontfamily', pf.app.font().family()),
+        # _I('gui/fontsize', pf.app.font().pointSize()),
         ]
+    toolbartip = "Currently, changing the toolbar position will only be in effect when you restart pyFormex"
+    gui_components = [
+        _I('gui/%s'%t, pf.cfg['gui/%s'%t], text=getattr(pf.GUI, t).windowTitle(), choices=['left', 'right', 'top', 'bottom'], itemtype='radio', tooltip=toolbartip) for t in ['camerabar', 'modebar', 'viewbar']
+        ]
+    # Use _ to avoid adding these items in the config
+    gui_buttons = [
+        _I('_gui/%sbutton'%t, t in pf.cfg['gui/actionbuttons'], text="%s Button" % t.capitalize()) for t in _actionbuttons
+        ]
+    gui_options1 = [
+        _I('gui/console', gui_console_options[pf.cfg['gui/console']], choices=list(gui_console_options.values()), text="Board"),
+        _I('gui/redirect', pf.cfg['gui/redirect']),
+        _I('gui/coordsbox'),
+        _I('gui/timeoutbutton', pf.cfg['gui/timeoutbutton']),
+        _I('gui/timeoutvalue', pf.cfg['gui/timeoutvalue']),
+    ]
+    gui_options2 = [
+        _I('gui/frontview', pf.cfg['gui/defviews'], itemtype='hradio', choices=['xy', 'xz'], tooltip="Axes defining the front view"),
+        _I('gui/showfocus', pf.cfg['gui/showfocus']),
+        _I('gui/buttonsattop', pf.cfg['gui/buttonsattop']),
+        _I('gui/allow_old_dialog_items', pf.cfg['gui/allow_old_dialog_items']),
+        _I('gui/easter_egg', pf.cfg['gui/easter_egg']),
+    ]
+    gui_settings = [
+        _G('Appearance', gui_appearance),
+        _G('Components', [
+            _C('col1', gui_components),
+            _C('col2', gui_buttons, spacer=True),
+        ]),
+        _G('Options', [
+            _C('col1',gui_options1),
+            _C('col2',gui_options2),
+        ]),
+    ]
 
+    ##### CANVAS settings #####
+    canvas_settings = [
+        _I('_not_active_', 'The canvas settings can be set from the Viewport Menu', itemtype='info', text=''),
+    ]
+
+    ##### DRAWING settings #####
+    drawing_settings = [
+        _I('draw/rendermode', pf.cfg['draw/rendermode'], choices=list(canvas.CanvasSettings.RenderProfiles)),
+        _I('draw/wait', pf.cfg['draw/wait']),
+        _I('draw/picksize', pf.cfg['draw/picksize']),
+        _I('draw/disable_depth_test', pf.cfg['draw/disable_depth_test'], text='Disable depth testing for transparent actors'),
+        _I('render/avgnormaltreshold', pf.cfg['render/avgnormaltreshold']),
+        _I('_info_00_', '', itemtype='info', text='Changes to the options below will only become effective after restarting pyFormex!'),
+        _I('draw/quadline', text='Draw as quadratic lines', itemtype='list', check=True, choices=ElementType.list(1), tooltip='Line elements checked here will be drawn as quadratic lines whenever possible.'),
+        _I('draw/quadsurf', text='Draw as quadratic surfaces', itemtype='list', check=True, choices=ElementType.list(2)+ElementType.list(3), tooltip='Surface and volume elements checked here will be drawn as quadratic surfaces whenever possible.'),
+
+    ]
+    ##### MOUSE settings #####
+    mouse_settings = autoSettings(['gui/rotfactor', 'gui/panfactor', 'gui/zoomfactor', 'gui/autozoomfactor', 'gui/dynazoom', 'gui/wheelzoom', 'gui/wheelzoomfactor'])
+
+
+    ##### WEBGL settings #####
     scripts = [
         pf.cfg['webgl/script'],
 #        "https:///fewgl-0.2.js",
@@ -220,81 +280,39 @@ def settings():
         ('webgl/devel', True, 'webgl/devpath'),
         ])
 
-
-    dia = widgets.InputDialog(
+    ##### ENVIRONMENT settings #####
+    mail_settings = [
+        _I('mail/sender', pf.cfg['mail/sender'], text="My mail address"),
+        _I('mail/server', pf.cfg['mail/server'], text="Outgoing mail server")
+        ]
+    environment_settings = [
+        _G('Mail', mail_settings),
+        # _G('Jobs',jobs_settings),
+    ]
+    dia = widgets.Dialog(
         caption='pyFormex Settings',
         store=pf.cfg,
-        scroll=True,        # This has huge input pages
+        scroll=True,        # This may have some large input pages
         size=(0.6, 0.9),
-        buttonsattop=True,  # Put buttons at top
+        buttonsattop=True,  # Put buttons at top (For all users)
         items=[
-            _T('General', [
-                _I('syspath', tooltip="If you need to import modules from a non-standard path, you can supply additional paths to search here."),
-                _I('editor', tooltip="The command to be used to edit a script file. The command will be executed with the path to the script file as argument."),
-                _I('viewer', tooltip="The command to be used to view an HTML file. The command will be executed with the path to the HTML file as argument."),
-                _I('browser', tooltip="The command to be used to browse the internet. The command will be executed with an URL as argument."),
-                _I('help/docs'),
-                _I('autorun', text='Startup script', tooltip='This script will automatically be run at pyFormex startup'),
-                _I('scriptdirs', text='Script Paths', tooltip='pyFormex will look for scripts in these directories', buttons=[('Edit', changeScriptDirs)]),
-                _I('appdirs', text='Applicationt Paths', tooltip='pyFormex will look for applications in these directories', buttons=[('Edit', changeAppDirs)]),
-                _I('autoglobals', text='Auto Globals', tooltip='If checked, global Application variables of any Geometry type will automatically be copied to the pyFormex global variable dictionary (PF), and thus become available in the GUI'),
-                _I('showapploaderrors', text='Show Application Load Error Traceback', tooltip='If checked, a traceback of exceptions occurring at Application Load time will be output. If unchecked, such exceptions will be suppressed, and the application will not run.'),
-                _I('openlastproj', text="Reload last project on startup"),
-                _I('check_print', text="Check scripts for the use of the print statement"),
-                _I('plot2d', text="Prefered 2D plot library", choices=['matplotlib', 'gnuplot']),
-                ],
-               ),
-            _T('Startup', [
-                _I('_info_01_', 'The settings on this page will only become active after restarting pyFormex', itemtype='info'),
-                _I('gui/bindings', bindings_current, choices=bindings_choices, tooltip="The Python bindings for the Qt libraries"),
-                #_I('gui/interpreter',interpreter_current,choices=interpreter_choices,tooltip="The Python interpreter to use for the message board"),
-                _I('gui/splash', text='Splash image', itemtype='filename', filter='img', exist=True, preview=splashviewer),
-                splashviewer,
-                ]),
-            _T('GUI', [
-                _G('Appearance', appearance),
-                _G('Components', toolbars + [
-                    _I('gui/frontview', pf.cfg['gui/defviews'], itemtype='hradio', choices=['xy', 'xz'], tooltip="Axes defining the front view"),
-                ] + actionbuttons + [
-                    _I('gui/console', gui_console_options[pf.cfg['gui/console']], itemtype='hradio', choices=list(gui_console_options.values()), text="Board"),
-                    _I('gui/redirect', pf.cfg['gui/redirect']),
-                    _I('gui/coordsbox'),
-                    _I('gui/showfocus', pf.cfg['gui/showfocus']),
-                    _I('gui/runalloption', pf.cfg['gui/runalloption']),
-                    _I('gui/timeoutbutton', pf.cfg['gui/timeoutbutton']),
-                    _I('gui/timeoutvalue', pf.cfg['gui/timeoutvalue']),
-                    _I('gui/easter_egg', pf.cfg['gui/easter_egg']),
-                    ],
-                 ),
-                ]),
-            _T('Canvas', [
-                _I('_not_active_', 'The canvas settings can be set from the Viewport Menu', itemtype='info', text=''),
-                ]),
-            _T('Drawing', [
-                _I('draw/rendermode', pf.cfg['draw/rendermode'], choices=canvas.CanvasSettings.RenderProfiles),
-                _I('draw/wait', pf.cfg['draw/wait']),
-                _I('draw/picksize', pf.cfg['draw/picksize']),
-                _I('draw/disable_depth_test', pf.cfg['draw/disable_depth_test'], text='Disable depth testing for transparent actors'),
-                _I('render/avgnormaltreshold', pf.cfg['render/avgnormaltreshold']),
-                _I('_info_00_', '', itemtype='info', text='Changes to the options below will only become effective after restarting pyFormex!'),
-                _I('draw/quadline', text='Draw as quadratic lines', itemtype='list', check=True, choices=ElementType.list(1), tooltip='Line elements checked here will be drawn as quadratic lines whenever possible.'),
-                _I('draw/quadsurf', text='Draw as quadratic surfaces', itemtype='list', check=True, choices=ElementType.list(2)+ElementType.list(3), tooltip='Surface and volume elements checked here will be drawn as quadratic surfaces whenever possible.'),
-                ]),
+            _T('General', general_settings),
+            _T('Startup', startup_settings),
+            _T('GUI', gui_settings),
+            _T('Canvas', canvas_settings),
+            _T('Drawing', drawing_settings),
             _T('Mouse', mouse_settings),
             _T('Plugins', plugin_items),
             _T('WebGL', webgl_settings),
-            _T('Environment', [
-                _G('Mail', mail_settings),
-#                _G('Jobs',jobs_settings),
-                ]),
-            ],
-        enablers=enablers,
+            _T('Environment', environment_settings),
+        ],
+        # enablers=enablers,
         actions=[
             ('Close', close),
-            ('Accept and Save', acceptAndSave),
-            ('Accept', accept),
-            ],
-        )
+            ('Apply and Continue', accept),
+            ('Accept, Save and Close', acceptAndSave),
+        ],
+    )
     dia.show()
 
 
@@ -321,7 +339,7 @@ def askConfigPreferences(items, prefix=None, store=None):
     itemlist = [_I(i, store[i]) for i in items] + [
         _I('_save_', True, text='Save changes')
         ]
-    res = widgets.InputDialog(itemlist, 'Config Dialog', pf.GUI).getResults()
+    res = widgets.Dialog(itemlist, 'Config Dialog', pf.GUI).getResults()
     #pf.debug(res,pf.DEBUG.CONFIG)
     if res and store==pf.cfg:
         updateSettings(res)
@@ -365,10 +383,10 @@ def setRendering():
             dia['render/'+f].setEnabled(on)
         dia['material'].setEnabled(on)
 
-    def updateLightParams(matname):
+    def updateLightParams(item):
         if dia is None:
             return
-        matname=str(matname)
+        matname = item.value()
         mat = pf.GUI.materials[matname]
         val = utils.prefixDict(mat.dict(), 'material/')
         dia.updateData(val)
@@ -377,7 +395,8 @@ def setRendering():
         dia.close()
 
     def accept(save=False):
-        dia.acceptData()
+        if not dia.validate():
+            return
         print("RESULTS", dia.results)
         if dia.results['render/mode'].startswith('smooth'):
             res = utils.subDict(dia.results, 'render/', strip=False)
@@ -424,30 +443,42 @@ def setRendering():
             light = pf.cfg['light/%s'%name]
             items = _T(name, [
                 _I("enabled", text="Enabled", value=light['enabled']),
-                _I("ambient", text="Ambient", value=light['ambient'], itemtype='color', func=changeLight),
-                _I("diffuse", text="Diffuse", value=light['diffuse'], itemtype='color', func=changeLight),
-                _I("specular", text="Specular", value=light['specular'], itemtype='color', func=changeLight),
-                _I("position", text="Position", value=light['position'][:3], itemtype='point'),
+                _I("ambient", text="Ambient", value=light['ambient'],
+                    itemtype='color', func=changeLight),
+                _I("diffuse", text="Diffuse", value=light['diffuse'],
+                    itemtype='color', func=changeLight),
+                _I("specular", text="Specular", value=light['specular'],
+                    itemtype='color', func=changeLight),
+                _I("position", text="Position", value=light['position'][:3],
+                    itemtype='point'),
                 ])
             light_items.append(items)
 
         items = [
-            _I('render/mode', vp.rendermode, text='Rendering Mode', itemtype='select', choices=draw.renderModes()),  # ,onselect=enableLightParams),
+            _I('render/mode', vp.rendermode, text='Rendering Mode',
+                choices=draw.renderModes()),  # ,func=enableLightParams),
             _I('render/lighting', vp.settings.lighting, text='Use Lighting'),
-            _I('render/ambient', vp.lightprof.ambient, itemtype='slider', min=0, max=100, scale=0.01, func=set_render_value, text='Global Ambient Lighting'),
-
+            _I('render/ambient', vp.lightprof.ambient, itemtype='slider',
+                min=0, max=100, scale=0.01, func=set_render_value,
+               text='Global Ambient Lighting'),
             _G('light', text='Lights', items=light_items),
-            _I('render/material', vp.material.name, text='Material', choices=matnames, onselect=updateLightParams),
+            _I('render/material', vp.material.name, text='Material',
+                choices=matnames, func=updateLightParams),
             _G('material', text='Material Parameters', items=[
-                _I(a, text=a, value=getattr(mat, a), itemtype='slider', min=0, max=100, scale=0.01, func=set_mat_value) for a in ['ambient', 'diffuse', 'specular', 'emission']] + [
-                _I(a, text=a, value=getattr(mat, a), itemtype='slider', min=1, max=128, scale=1., func=set_mat_value) for a in ['shininess']
+                _I(a, text=a, value=getattr(mat, a), itemtype='slider',
+                    min=0, max=100, scale=0.01,
+                    func=set_mat_value) for a in [
+                        'ambient', 'diffuse', 'specular', 'emission']] + [
+                _I(a, text=a, value=getattr(mat, a), itemtype='slider',
+                    min=1, max=128, scale=1.,
+                   func=set_mat_value) for a in ['shininess']
                 ]),
             ]
 
         enablers = [
             ('render/lighting', True, 'render/ambient', 'render/material', 'material'),
             ]
-        dia = widgets.InputDialog(
+        dia = widgets.Dialog(
             caption='pyFormex Settings',
             enablers = enablers,
             #store=pf.cfg,
@@ -455,9 +486,9 @@ def setRendering():
             #prefix='render/',
             autoprefix=True,
             actions=[
-                ('Close', close),
+                ('Cancel', close),
                 ('Apply and Save', acceptAndSave),
-                ('Apply', accept),
+                ('Apply for this session', accept),
                 ]
             )
         enableLightParams(vp.rendermode)
@@ -543,7 +574,7 @@ def createDirsDialog(dircfg):
         appMenu.reloadMenu(mode=mode)
 
     data = [list(c) for c in pf.cfg[dircfg]]
-    _dia = widgets.InputDialog(
+    _dia = widgets.Dialog(
         items = [
             _I(dircfg, data, itemtype='table', chead = ['Label', 'Path']),
             ],
@@ -568,7 +599,7 @@ def setDebug():
     values = [getattr(pf.DEBUG, o) for o in options]
     items = [_I(o, bool(pf.options.debuglevel & v)) for o, v in zip(options, values)]
     n = (len(options)+1) // 2
-    cols = [_H('col', items[:n]), _H('col', items[n:]), ]
+    cols = [_C('col', items[:n]), _C('col', items[n:]), ]
     res = draw.askItems(cols)
     if res:
         print(res)
