@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -36,7 +36,6 @@ from pyformex.opengl import canvas
 from pyformex.gui.draw import _I
 from .Settings import updateSettings
 
-
 def setTriade():
     try:
         pos = pf.canvas.triade.pos
@@ -46,7 +45,8 @@ def setTriade():
         size = 50
     res = draw.askItems([
         _I('triade', True),
-        _I('pos', pos, choices=['lt', 'lc', 'lb', 'ct', 'cc', 'cb', 'rt', 'rc', 'rb']),
+        _I('pos', pos, choices=[
+            'lt', 'lc', 'lb', 'ct', 'cc', 'cb', 'rt', 'rc', 'rb']),
         _I('size', size),
         ])
     if res:
@@ -104,12 +104,13 @@ def setBgColor():
     viewer = widgets.ImageView(cur, maxheight=200)
 
     def changeColor(field):
-        bgcolor_dialog.acceptData()
+        if not bgcolor_dialog.validate():
+            return
         res = bgcolor_dialog.results
         if res:
             setBackground(**res)
 
-    bgcolor_dialog = widgets.InputDialog(
+    bgcolor_dialog = widgets.Dialog(
         [
             _I('mode', mode, choices=bgmodes),
             _I('color1', color[0], itemtype='color', func=changeColor, text='Background color 1 (Bottom Left)'),
@@ -219,7 +220,8 @@ def canvasSettings():
 
 
     def accept(save=False):
-        dia.acceptData()
+        if not dia.validate():
+            return
         res = dia.results
         vp = getVp(res['viewport'])
         pf.debug("Changing Canvas settings for viewport %s to:\n%s"%(pf.GUI.viewports.viewIndex(vp), res), pf.DEBUG.CANVAS)
@@ -236,7 +238,8 @@ def canvasSettings():
     def acceptAndSave():
         accept(save=True)
 
-    def changeViewport(vp):
+    def changeViewport(item):
+        vp = item.value()
         if vp == 'current':
             vp = pf.GUI.viewports.current
         elif vp == 'focus':
@@ -250,11 +253,13 @@ def canvasSettings():
     pf.debug("Focus: %s; Current: %s" % (canv, vp), pf.DEBUG.CANVAS)
     s = canv.settings
 
-    dia = widgets.InputDialog(
+    vp_choices = ['focus', 'current'] + [
+        str(i) for i in range(len(pf.GUI.viewports.all))]
+    dia = widgets.Dialog(
         caption='Canvas Settings',
         store=canv.settings,
         items=[
-            _I('viewport', choices=['focus', 'current']+[str(i) for i in range(len(pf.GUI.viewports.all))], onselect=changeViewport),
+            _I('viewport', choices=vp_choices, func=changeViewport),
             _I('pointsize',),
             _I('linewidth',),
             _I('linestipple',),
@@ -348,12 +353,12 @@ def cameraSettings():
 def openglSettings():
     dia = None
     def apply_():
-        dia.acceptData()
-        canvas.glSettings(dia.results)
+        if dia.validateData():
+            canvas.glSettings(dia.results)
     def close():
         dia.close()
 
-    dia = widgets.InputDialog(
+    dia = widgets.Dialog(
         caption='OpenGL Settings',
         items=[
             _I('Line Smoothing', 'Off', itemtype='radio', choices=['On', 'Off']),
