@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -31,15 +31,6 @@ anywhere, causing attached functions to be executed.
 from pyformex.gui import QtCore
 from pyformex.gui import Signal
 
-# These have to disappear
-SIGNAL = QtCore.SIGNAL
-
-# signals
-CANCEL = SIGNAL("Cancel")   # cancel the operation, undoing it
-DONE   = SIGNAL("Done")     # accept and finish the operation
-TIMEOUT = SIGNAL("Timeout")  # terminate what was going on
-
-
 
 class Signals(QtCore.QObject):
     """A class with all custom signals in pyFormex.
@@ -56,6 +47,7 @@ class Signals(QtCore.QObject):
     - TIMEOUT: terminate what was going on
     - SAVE: save current rendering
     - FULLSCREEN: toggle fullscreen mode
+    - VALIDATED: the dialog data were validated
     """
     CANCEL = Signal()
     DONE   = Signal()
@@ -64,6 +56,7 @@ class Signals(QtCore.QObject):
     TIMEOUT = Signal()
     SAVE = Signal()
     FULLSCREEN = Signal()
+    VALIDATED = Signal()
 
 
 
