@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -381,8 +381,6 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
 
         # Define our private signals
         self.signals = self.Communicate()
-        self.CANCEL = self.signals.CANCEL
-        self.DONE   = self.signals.DONE
         #
         self.setMinimumSize(32, 32)
         self.setSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
@@ -789,8 +787,8 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
             self.setMouse(LEFT, self.mouse_pick, CTRL)
             self.setMouse(RIGHT, self.emit_done)
             self.setMouse(RIGHT, self.emit_cancel, SHIFT)
-            self.DONE.connect(self.accept_selection)
-            self.CANCEL.connect(self.cancel_selection)
+            self.signals.DONE.connect(self.accept_selection)
+            self.signals.CANCEL.connect(self.cancel_selection)
             self.pick_mode = mode
             self.pickable = pickable
             self.selection_front = None
@@ -829,8 +827,8 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         self.resetMouse(LEFT, CTRL)
         self.resetMouse(RIGHT)
         self.resetMouse(RIGHT, SHIFT)
-        self.DONE.disconnect(self.accept_selection)
-        self.CANCEL.disconnect(self.cancel_selection)
+        self.signals.DONE.disconnect(self.accept_selection)
+        self.signals.CANCEL.disconnect(self.cancel_selection)
         self.pick_mode = None
         self.pickable = None
         pf.debug("FINISH SELECTION DONE", pf.DEBUG.GUI)
@@ -1068,8 +1066,8 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         self.setMouse(LEFT, self.mouse_draw)
         self.setMouse(RIGHT, self.emit_done)
         self.setMouse(RIGHT, self.emit_cancel, SHIFT)
-        self.DONE.connect(self.accept_draw)
-        self.CANCEL.connect(self.cancel_draw)
+        self.signals.DONE.connect(self.accept_draw)
+        self.signals.CANCEL.connect(self.cancel_draw)
         self.drawmode = mode
         self.zplane = float(zplane)
         self.drawing = Coords(coords)
@@ -1079,8 +1077,8 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         self.resetMouse(LEFT)
         self.resetMouse(RIGHT)
         self.resetMouse(RIGHT, SHIFT)
-        self.DONE.disconnect(self.accept_draw)
-        self.CANCEL.disconnect(self.cancel_draw)
+        self.signals.DONE.disconnect(self.accept_draw)
+        self.signals.CANCEL.disconnect(self.cancel_draw)
         self.drawmode = None
 
     def accept_draw(self, clear=False):
@@ -1182,8 +1180,8 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         self.setMouse(LEFT, self.mouse_draw_line)
         self.setMouse(RIGHT, self.emit_done)
         self.setMouse(RIGHT, self.emit_cancel, SHIFT)
-        self.DONE.connect(self.accept_drawing)
-        self.CANCEL.connect(self.cancel_drawing)
+        self.signals.DONE.connect(self.accept_drawing)
+        self.signals.CANCEL.connect(self.cancel_drawing)
         #self.setCursorShape('pick')
         self.drawing_mode = mode
         self.edit_mode = None
@@ -1204,8 +1202,8 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         self.resetMouse(LEFT)
         self.resetMouse(RIGHT)
         self.resetMouse(RIGHT, SHIFT)
-        self.DONE.disconnect(self.accept_drawing)
-        self.CANCEL.disconnect(self.cancel_drawing)
+        self.signals.DONE.disconnect(self.accept_drawing)
+        self.signals.CANCEL.disconnect(self.cancel_drawing)
         self.drawing_mode = None
 
     def accept_drawing(self, clear=False):
@@ -1377,14 +1375,14 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
 
         This is equivalent to pressing the ENTER button."""
         if action == RELEASE:
-            self.DONE.emit()
+            self.signals.DONE.emit()
 
     def emit_cancel(self, x, y, action):
         """Emit a CANCEL event by clicking the mouse.
 
         This is equivalent to pressing the ESC button."""
         if action == RELEASE:
-            self.CANCEL.emit()
+            self.signals.CANCEL.emit()
 
 
     def draw_state_rect(self, x, y):
@@ -1532,10 +1530,10 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         # Make the clicked viewport the current one
         pf.GUI.signals.WAKEUP.emit()
         if e.key() == ESC:
-            self.CANCEL.emit()
+            self.signals.CANCEL.emit()
             e.accept()
         elif e.key() == ENTER or e.key() == RETURN:
-            self.DONE.emit()
+            self.signals.DONE.emit()
             e.accept()
         else:
             e.ignore()
