@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -103,6 +103,7 @@ warn_flat_removed = "The 'flat=True' parameter of the draw function has been rep
 warn_formex_eltype = "Formex eltype currently needs to be a string!"
 warn_formex_rosette = "The 'point' option of Formex.rosette has been renamed to 'around'"
 warn_inertia_changed = "The Coords.inertia method has changed: it now returns an inertia.Inertia class instance, with attributes mass, ctr, tensor, and method principal() returning (Iprin,Iaxes)."
+warn_inputcombo_onselect = "InputCombo: the use of onselect is deprecated. Use 'func' instead. It receives the InputItem as parameter."
 warn_Interaction_changed = "Class fe_abq.Interaction has been changed, only allowed parameters are name, friction, surfacebehavior, surfaceinteraction, extra (see doc)."
 warn_mesh_extrude = "Mesh.extrude parameters have changed. The signature is now  extrude(div,dir,length) where length is the total extrusion length."
 warn_mesh_connect = "Mesh.connect does no longer automatically compact the Meshes. You may have to use the Mesh.compact method to do so."
@@ -132,7 +133,6 @@ warn_properties_setname = "!! 'setname' is deprecated, please use 'name'"
 
 warn_regular_grid = "The function simple.regularGrid has changed!. The points are now ordered first along the 0-axis, then along the 1-axis, etc... This is to be consistent with other grid numbering schemes in pyFormex. The old numbering scheme (first along the highest axis) can be obtained by passing the 'swapaxes=True' argument to the function."
 warn_select_changed = "The select and cselect methods have changed for Mesh type opbjects. The default is now compact=False, as suggested in https://savannah.nongnu.org/bugs/?40662#comment7. If you want to get the result compacted, use clip/cclip instead, or add '.compact()'"
-warn_widgets_updatedialogitems = "gui.widgets.updateDialogItems now expects data in the new InputItem format. Use gui.widgets.updateOldDialogItems for use with old data format."
 warn_radio_enabler = "A 'radio' type input item can currently not be used as an enabler for other input fields."
 warn_viewport_linking = "Linking viewports is an experimental feature and is not fully functional yet."
 warn_vmtk_includeprop = "includeprop %s are in the property set %s. Remesh will not have any effect."
@@ -140,15 +140,9 @@ warn_writevtp_notclean = "Mesh is not clean: vtk will alter the nodes. To clean:
 warn_writevtp_duplicates = "Mesh contains duplicate elements. This may give problems in VTK / ParaView.\n Duplicates: %s "
 warn_writevtp_shape = "The number of array cells should be equal to the number of elements"
 warn_writevtp_shape2 = "The number of array points should be equal to the number of points"
-# Commented out as it is unused and raises a DeprecationWarning
-# warn_vtkboxplanes_removed = "The method boxplanes has been removed. If the implicit data are coordinates defining a bounding box use\n\n\
-# from pyformex.simple import cuboid \n\
-# vtkClip(mesh,implicitdata=cuboid(\*bbox).toSurface(),method='surface')\n\n\
-# vtkCut(mesh,implicitdata=cuboid(\*bbox).toSurface(),method='surface')\n\n\
-# If the implicit data are a hexahdral box use\n\n\
-# vtkClip(mesh,implicitdata=box.toSurface(),method='surface')\n\n\
-# vtkCut(mesh,implicitdata=box.toSurface(),method='surface')\n\n\
-# "
+warn_trfMatrix_deprecated = "trfMatrix is deprecated. Use trfmat instead."
+warn_vectorRotation_deprecated = "vectorRotation is deprecated. Use rotMatrix2 instead."
+warn_rotationAnglesFromMatrix_deprecated = "rotationAnglesFromMatrix is deprecated. Use cardanAngles instead."
 
 error_widgets_enableitem = "Error in a dialog item enabler. This should not happen! Please file a bug report."
 error_no_gts_bin = "I am missing the gts binary programs on your system.\nTherefore, some surface operations will not be available or fail.\n\nOn Debian, you can install the missing programs with `apt-get install libgts-bin`.\n"
@@ -156,18 +150,14 @@ error_no_gts_extra = "I am missing the gts binary programs on your system.\nTher
 
 depr_mesh_getlowerentities_unique = "The use of the unique argument in getLowerEntities is deprecated. Use \n sel = self.elType().getEntities(level) \n lower = self.elems.insertLevel(sel)[1] "
 depr_pathextension = "patchextension is deprecated. Use border().extrude() instead."
-
-PolyLine_distanceOfPoints = "PolyLine.distanceOfPoints is deprecated"
-PolyLine_distanceOfPolyline = "PolyLine.distanceOfPolyline is deprecated"
-
 depr_abqdata_outres = "The use of the `res` and `out` arguments in AbqData is deprecated. Set them inside your Steps instead."
 depr_avgNodalScalarOnAdjacentNodes = "avgNodalScalarOnAdjacentNodes is deprecated. It may be removed in future, unless someone can prove its virtue, generalize, cleanup and document the code and provide an example. See the source code for more comments."
 depr_connectionSteps1 = "connectionSteps is deprecated and has been removed. Use frontWalk instead. See the FrontWalk example: walk 3 gives an equivalent result, though you might prefer the simpler solution of walk 2."
 depr_anyVector = "arraytools.anyVector is deprecated. Use checkArray([1,2,3],shape=(3,),kind='f',allow='i') instead."
 depr_connectedLineElems = "connectivity.connectedLineElems is deprecated. You should use Connectivity.chained or Connectivity.chain instead. Please read the docstring: the arguments and return values are different!"
-warn_trfMatrix_deprecated = "trfMatrix is deprecated. Use trfmat instead."
-warn_vectorRotation_deprecated = "vectorRotation is deprecated. Use rotMatrix2 instead."
-warn_rotationAnglesFromMatrix_deprecated = "rotationAnglesFromMatrix is deprecated. Use cardanAngles instead."
+
+PolyLine_distanceOfPoints = "PolyLine.distanceOfPoints is deprecated"
+PolyLine_distanceOfPolyline = "PolyLine.distanceOfPolyline is deprecated"
 
 VTK_strips = "There are strips in the VTK object (not yet supported in pyFormex). I will convert it to triangles."
 
