@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -994,7 +994,7 @@ class Camera(object):
         here in an optimized way.
         """
         x = at.checkArray(x, (3,), 'f') + [0., 0., self.dist]
-        return np.dot(x, self.rot.T) + self.focus
+        return x @ self.rot.T + self.focus
 
 
 #################################################################
@@ -1069,11 +1069,11 @@ class Camera(object):
     def project(self, x):
         """Map the world coordinates (x,y,z) to window coordinates."""
         # Modelview transform
-        e = np.dot(Vector4(x), self.modelview)
+        e = Vector4(x) @ self.modelview
         #print("EYE COORDINATES:",e)
         w = -e[:, 2]
         # Projection
-        x = np.dot(e, self.projection)
+        x = e @ self.projection
         #print("CLIP COORDINATES:",x)
         # Perspective division
         if self._perspective:
@@ -1087,14 +1087,14 @@ class Camera(object):
 
     def unproject(self, x):
         """Map the window coordinates x to object coordinates."""
-        m = np.dot(self.modelview, self.projection)
+        m = self.modelview @ self.projection
         #print("M*P",m)
         m1 = np.linalg.inv(m)
         #print("M*P -1",m1)
         x = self.fromWindow(x)
         #print("NORMALIZED DEVICE COORDINATES:",x)
-        x = np.dot(Vector4(x), m1)
-        return Coords(x[:, :3] / x[:, 3])
+        x = Coords4(x) @ m1
+        return x.toCoords()
 
 
     def inside(self, x, rect=None, return_depth=False):
