@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -60,18 +60,30 @@ from collections import OrderedDict
 def GLcolor(color):
     """Convert a color to an OpenGL RGB color.
 
-    The output is a tuple of three RGB float values ranging from 0.0 to 1.0.
-    The input can be any of the following:
+    Parameters
+    ----------
+    color: :term:`color_like`
+        Data specifying an RGB color. THis can be any of the following:
 
-    - a QColor
-    - a string specifying the X11 name of the color
-    - a hex string '#RGB' with 1 to 4 hexadecimal digits per color
-    - a tuple or list of 3 integer values in the range 0..255
-    - a tuple or list of 3 float values in the range 0.0..1.0
+        - a QColor
+        - a string specifying the X11 name of the color
+        - a hex string '#RGB' with 1 to 4 hexadecimal digits per color
+        - a tuple or list of 3 integer values in the range 0..255
+        - a tuple or list of 3 float values in the range 0.0..1.0
+        - a single float value in the range 0.0..1.0: this will be converted
+          to a grey value
 
-    Any other input may give unpredictable results.
+    Returns
+    -------
+    tuple
+        A tuple of three RGB float values in the range 0.0..1.0.
 
-    Examples:
+    Raises
+    ------
+    ValueError: If the input is not one of the accepted data.
+
+    Examples
+    --------
     >>> GLcolor('red')
     (1.0, 0.0, 0.0)
     >>> GLcolor('indianred') # doctest: +ELLIPSIS
