@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -420,7 +420,7 @@ def seeding3zones(nseeds=[10, 10], zonesizes=[0.3, 0.3]):
     #geometrical series: nextsegment = previoussegment**power
     ntransseeds= ((log(near1/near0)) / log((transzone+near1)/(transzone+near0))) -1.
     powertrans=(near1/near0)**(1./(ntransseeds+1.))
-    napproxseeds=round(ntransseeds)
+    napproxseeds=int(round(ntransseeds))
     xtrans= near0*array([(powertrans**i) for i in range(1, napproxseeds+1)])
     xtrans= cumsum(xtrans)
     xtrans=xtrans[:-1]*transzone/xtrans[-1]
@@ -449,7 +449,8 @@ def inputLongitudinalSeeds():
         """Show the current seeds"""
         global dialog, SA
         undraw(SA)
-        dialog.acceptData()
+        if not dialog.validate():
+            return
         res = dialog.results
         if not res:
             return
