@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -28,9 +28,8 @@
 Some extra tools to handle the camera.
 """
 
-
 import pyformex as pf
-from pyformex.gui.widgets import simpleInputItem as _I, InputDialog as Dialog
+from pyformex.gui.widgets import simpleInputItem as _I, Dialog
 from pyformex.arraytools import stuur
 
 dialog = None
@@ -41,12 +40,12 @@ def getCameraSettings(cam):
 
 def apply():
     global dialog
-    dialog.acceptData()
-    settings = dialog.results
-    #print settings
-    cam = pf.canvas.camera
-    cam.setClip(settings['near'], settings['far'])
-    pf.canvas.update()
+    if dialog.validate():
+        settings = dialog.results
+        #print settings
+        cam = pf.canvas.camera
+        cam.setClip(settings['near'], settings['far'])
+        pf.canvas.update()
 
 
 def close():
@@ -105,13 +104,10 @@ def showCameraTool():
                     default='Close',
                     )
 
-    dialog.show()
-
     cam.modelview_callback = updateSettings
 
 
 if __name__ == '__draw__':
     showCameraTool()
-    dialog.timeout = close
 
 # End
