@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -178,10 +178,8 @@ def drawObject2D(mode, npoints=-1, zvalue=0., coords=None):
 
 def selectObject(mode=None):
     selection = objects.drawAble(like=mode+'-')
-    res = widgets.ListSelection(
-        selection.listAll(),
-        caption='Known %ss' % mode,
-        sort=True).getResults()
+    res = selectItems(selection.listAll(), caption='Known %ss' % mode,
+        sort=True)
     # UNFINISHED
 
 ###################################
