@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -63,7 +63,8 @@ def configure():
         dia.close()
 
     def accept(save=False):
-        dia.acceptData()
+        if not dia.validate():
+            return
         res = dia.results
         res['_save_'] = save
         if res['_addhost_']:
@@ -88,7 +89,7 @@ def configure():
         _I('_addhost_', '', text="New host", tooltip="To set a host name that is not yet in the list of hosts, you can simply fill it in here."),
         ]
 
-    dia = widgets.InputDialog(
+    dia = widgets.Dialog(
         caption='pyFormex Settings',
         store=pf.cfg,
         items=jobs_settings,
@@ -347,15 +348,14 @@ def checkResultsOnServer(host=None, userdir=None):
     """
     global the_host, the_userdir, the_jobnames
     if host is None or userdir is None:
-        res = askItems(
-            [_I('host', None, 'select', choices=['bumpfs', 'bumpfs2', 'other']),
-              _I('other', '', text='Other host name'),
-              _I('status', None, 'select', choices=['results', 'running', 'custom']),
-              _I('userdir', 'bumper/results/', text='Custom user directory'),
-            ], enablers=[
-                ('status', 'custom', 'userdir')
-                ]
-            )
+        res = askItems([
+            _I('host', choices=['bumpfs', 'bumpfs2', 'other']),
+            _I('other', '', text='Other host name'),
+            _I('status', choices=['results', 'running', 'custom']),
+            _I('userdir', 'bumper/results/', text='Custom user directory'),
+        ], enablers=[
+            ('status', 'custom', 'userdir')
+        ])
         if not res:
             return
         host = res['host']
