@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -193,11 +193,11 @@ class Objects(object):
         choices = self.listAll()
         if not choices:
             return None
-        res = widgets.ListSelection(
+        res = selectItems(
             caption='Known %sobjects' % self.object_type(),
             choices=self.listAll(),
             default=self.names,
-            sort=True).getResults()
+            sort=True)
         if res is None:
             res = []
         self.set(res)
