@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -24,14 +24,13 @@
 """Postprocessing Menu
 
 """
+from collections import OrderedDict
 
-from numpy import *
+import numpy as np
 
 import pyformex as pf
 from pyformex import utils
 from pyformex.gui import menu, QtGui, QtCore, QtWidgets
-
-from collections import OrderedDict
 from pyformex.lazy import *
 from pyformex.gui.colorscale import ColorScale
 from pyformex.opengl.decors import ColorLegend
@@ -717,10 +716,8 @@ def checkDB():
     return isinstance(DB, FeResult)
 
 
-def dialog_getresults():
+def shortkey_results(data):
     """Return the dialog data with short keys."""
-    dialog.acceptData()
-    data = dialog.results
     # TODO sanitize the use of list
     data['resindex'] = list(result_types.values()).index(data['restype'])
     return data
@@ -735,8 +732,9 @@ def dialog_reset(data=None):
 
 def show():
     """Show the results """
-    data = dialog_getresults()
-    show_results(data)
+    if dialog.validate():
+        data = shortkey_results(dialog.results)
+        show_results(data)
 
 
 def show_results(data):
@@ -835,7 +833,8 @@ def open_dialog():
         return
     close_dialog()
 
-    def set_inc_choices(step):
+    def set_inc_choices(item):
+        step = item.value()
         if step:  # to avoid an error when called before data set
             print("  Incs for step %s: %s" % (step, DB.getIncs(int(step))))
             dialog['inc'].setChoices(DB.getIncs(int(step)))
@@ -843,7 +842,7 @@ def open_dialog():
     input_items = [
         _T('Result', [
             _I('feresult', text='FE Result DB', value='', itemtype='info'),
-            _I('step', text='Step', choices=DB.getSteps(), onselect=set_inc_choices),
+            _I('step', text='Step', choices=DB.getSteps(), func=set_inc_choices),
             _I('inc', text='Increment', choices=[1]),
             _I('elgroup', text='Element Group', choices=['--ALL--', ]),
             _I('restype', text='Type of result', choices=list(result_types.values())),
@@ -908,7 +907,9 @@ def open_dialog():
 def close_dialog():
     global dialog
     if dialog:
-        pf.PF['PostProcMenu_data'] = dialog_getresults()
+        if dialog.validate():
+            data = shortkey_results(dialog.results)
+            pf.PF['PostProcMenu_data'] = data
         dialog.close()
         dialog = None
     if tbl:
