@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -136,7 +136,7 @@ def intersection(self, surf, check=False, verbose=False):
 
 
 def gtsset(self, surf, op, filt='', ext='', curve=False, check=False, verbose=False):
-    """_Perform the boolean/intersection methods.
+    """Perform boolean/intersection methods on TriSurfaces.
 
     See the boolean/intersection methods for more info.
     Parameters not explained there:
@@ -171,13 +171,15 @@ def gtsset(self, surf, op, filt='', ext='', curve=False, check=False, verbose=Fa
         self.write(tmp, 'gts')
         #print("Writing temp file %s" % tmp1)
         surf.write(tmp1, 'gts')
-        print("Performing boolean operation")
+        print(f"Performing boolean operation {op}")
         cmd = f"cd {tmpdir} && gtsset {options} {op} {tmp} {tmp1} {filt}"
-        P = utils.system(cmd, stdout=open(tmp2, 'w'), shell=True, verbose=verbose)
+        P = utils.system(
+            cmd, stdout=open(tmp2, 'w'), shell=True, verbose=verbose)
         if P.returncode or verbose:
             print(P.stdout)
         if P.returncode:
             print(P.stderr)
+            print("""The boolean procedure didn't return any results.""")
             return None
         if curve:
             res = read_gts_intersectioncurve(tmp2)
