@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -587,7 +587,8 @@ Most likely because 'python-scipy' is not installed on your system.""")
 
 
 def _show_stats(domain, dist):
-    _stat_dia.acceptData()
+    if not _stat_dia.validate():
+        return
     res = _stat_dia.results
     key = res['Value']
     if dist and res['Cumulative Distribution']:
@@ -630,17 +631,17 @@ def showStatisticsDialog():
 
     dispmodes = ['On Domain', 'Histogram', 'Cumulative Histogram']
     keys = list(SelectableStatsValues.keys())
-    _stat_dia = widgets.InputDialog(
+    _stat_dia = widgets.Dialog(
         caption='Surface Statistics', items=[
-            _H('', [
+            _C('', [
                 _I('Value', itemtype='vradio', choices=keys),
                 _I('neighbours', text='Curvature Neighbourhood', value=1),
                 _I('curval', text='Curvature Value', itemtype='vradio', choices=CurvatureValues),
             ]),
-            _H('', [
+            _C('', [
                 _I('clip', itemtype='hradio', choices=['None', 'Top', 'Bottom', 'Both']),
                 _I('Clip Mode', itemtype='hradio', choices=['Range', 'Percentile']),
-                _G('Clip Values', checkable=True, items=[
+                _G('Clip Values', check=True, items=[
                     _I('Top', 1.0),
                     _I('Bottom', 0.0),
                 ]),
@@ -996,7 +997,8 @@ def cutWithPlane():
             selection.set(['%s/pos' % n for n in selection] + ['%s/neg' % n for n in selection])
             selection.draw()
         else:
-            selection.changeValues([F.cutWithPlane(P, N, newprops=p, side=side, atol=atol) for F in FL])
+            selection.changeValues([F.cutWithPlane(
+                P, N, newprops=p, side=side, atol=atol) for F in FL])
             selection.drawChanges()
 
 
@@ -1011,12 +1013,17 @@ def cutSelectionByPlanes():
         warning("You have to define some planes first.")
         return
 
-    res1 = widgets.ListSelection(planes, caption='Known %sobjects' % selection.object_type(), sort=True).getResults()
+    res1 = selectItems(planes,
+                       caption='Known %sobjects' % selection.object_type(),
+                       sort=True)
     if res1:
-        res2 = askItems([_I('Tolerance', 0.),
-                         _I('Color by', 'side', itemtype='radio', choices=['side', 'element type']),
-                         _I('Side', 'both', itemtype='radio', choices=['positive', 'negative', 'both']),
-                         ], caption = 'Cutting parameters')
+        res2 = askItems([
+            _I('Tolerance', 0.),
+            _I('Color by', 'side', itemtype='radio',
+               choices=['side', 'element type']),
+            _I('Side', 'both', itemtype='radio',
+               choices=['positive', 'negative', 'both']),
+        ], caption = 'Cutting parameters')
         if res2:
             planes = [named(r) for r in res1]
             p = [plane.P for plane in planes]
@@ -1130,18 +1137,17 @@ def smooth():
     """Smooth the selected surface."""
     S = selection.check(single=True)
     if S:
-        res = askItems(
-            [_I('method', 'lowpass', itemtype='select', choices=['lowpass', 'laplace']),
-              _I('iterations', 1, min=1),
-              _I('lambda_value', 0.5, min=0.0, max=1.0),
-              _I('neighbourhood', 1),
-              _I('alpha', 0.0),
-              _I('beta', 0.2),
-              ], enablers=[
-                ('method', 'lowpass', 'neighbourhood'),
-                ('method', 'laplace', 'alpha', 'beta'),
-                ],
-            )
+        res = askItems([
+            _I('method', choices=['lowpass', 'laplace']),
+            _I('iterations', 1, min=1),
+            _I('lambda_value', 0.5, min=0.0, max=1.0),
+            _I('neighbourhood', 1),
+            _I('alpha', 0.0),
+            _I('beta', 0.2),
+        ], enablers=[
+            ('method', 'lowpass', 'neighbourhood'),
+            ('method', 'laplace', 'alpha', 'beta'),
+        ])
         if res:
             if not 0.0 <= res['lambda_value'] <= 1.0:
                 warning("Lambda should be between 0 and 1.")
