@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -221,11 +221,11 @@ def edit_point(pt):
     def close():
         dia.close()
     def accept():
-        dia.acceptData()
-        res = dia.results
-        return [res[i] for i in 'xyz']
+        if dia.validate():
+            res = dia.results
+            return [res[i] for i in 'xyz']
 
-    dia = widgets.InputDialog(
+    dia = widgets.Dialog(
         items = [_I(x=x, y=y, z=z), ]
         )
     dia.show()
