@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -132,7 +132,8 @@ def run(args, *, capture_output=True, encoding='utf-8', **kargs):
     - If a string is passed as `args` and `shell` is False, the string is
       automatically tokenized into an args list.
 
-    - The output of the command is captured by default.
+    - If no stdout nor stderr are specified, the output of the command
+      is captured by default. Use capture_output=False to not capture.
 
     - The `encoding` is set to 'utf-8' by default, so that stdout
       and stderr return as strings.
@@ -205,6 +206,10 @@ def run(args, *, capture_output=True, encoding='utf-8', **kargs):
     >>> P.stdout.strip('\\n') == os.getcwd()
     True
 
+    >>> P = run("pwd", stdout=subprocess.PIPE)
+    >>> P.stdout.strip('\\n') == os.getcwd()
+    True
+
     >>> P = run("echo 'This is stderr' > /dev/stderr", shell=True)
     >>> P.stderr
     'This is stderr\\n'
@@ -234,6 +239,18 @@ def run(args, *, capture_output=True, encoding='utf-8', **kargs):
     <BLANKLINE>
 
     """
+    # TODO: remove this when we make Python 3.7 the minimum
+    # FIX FOR PYTHON 3.6 (has no capture_output parameter)
+    import sys
+    if sys.hexversion < 0x03070000:
+        if capture_output and 'stdout' not in kargs and 'stderr' not in kargs:
+            kargs['stdout'] = subprocess.PIPE
+            kargs['stderr'] = subprocess.PIPE
+    else:
+        # REMOVE till here
+        if capture_output and 'stdout' not in kargs and 'stderr' not in kargs:
+            kargs['capture_output'] = True
+
     shell = bool(kargs.get('shell', False))
     if isinstance(args, str) and shell is False:
         # Tokenize the command line
@@ -241,22 +258,6 @@ def run(args, *, capture_output=True, encoding='utf-8', **kargs):
     if shell and 'executable' not in kargs:
         kargs['executable'] = os.environ.get('SHELL', '/bin/sh')
 
-    if 'stdout' not in kargs and 'stderr' not in kargs:
-        kargs['capture_output'] = capture_output
-
-    # TODO: remove this when we make Python 3.7 the minimum
-    # FIX FOR PYTHON 3.6 (has no capture_output parameter)
-    import sys
-    if sys.hexversion < 0x03070000:
-        if capture_output:
-            if ('stdout' in kargs) or ('stderr' in kargs):
-                raise ValueError('stdout and stderr arguments may not be used '
-                                 'with capture_output.')
-            kargs['stdout'] = subprocess.PIPE
-            kargs['stderr'] = subprocess.PIPE
-        del kargs['capture_output']
-    # REMOVE till here
-
     if encoding:
         kargs['encoding'] = encoding
     check = kargs.get('check', False)
@@ -303,7 +304,7 @@ def start(args, *, verbose=False, **kargs):
     Note
     ----
     This function will immediately return after creating the subprocess
-    and thus not wait for the command to terminate, nor return its
+    and does not wait for the command to terminate, nor return its
     outcome. The user if fully responsible for handling the communication
     with the process, its termination, and the capture of its outcome.
     If you just want to wait for the command to finish, and capture
