@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -456,7 +456,7 @@ def runScript(fn, argv=[]):
     return res
 
 
-def runApp(appname, argv=[], refresh=False, lock=True, check=True):
+def runApp(appname, argv=[], refresh=False, lock=True, check=True, wait=False):
     """Run a pyFormex application.
 
     A pyFormex application is a Python module that can be loaded in
@@ -476,10 +476,15 @@ def runApp(appname, argv=[], refresh=False, lock=True, check=True):
     """
     pf.debug(f"runApp '{appname}'", pf.DEBUG.APPS)
     global exitrequested
-    if check and len(pf.scriptlock) > 0:
-        print("!!Not executing because a script lock has been set: "
-              f"{pf.scriptlock}")
-        return
+    if check:
+        while len(pf.scriptlock) > 0:
+            if wait:
+                 print(f"!!Waiting for lock {pf.scriptlock} to be released")
+                 sleep(5)
+            else:
+                 print("!!Not executing because a script lock has been set: "
+                       f"{pf.scriptlock}")
+                 return
 
     from pyformex import apps
     from pyformex.timer import Timer
@@ -487,7 +492,7 @@ def runApp(appname, argv=[], refresh=False, lock=True, check=True):
     print(f"Loading application {appname} with refresh={refresh}")
     app = apps.load(appname, refresh=refresh)
     if app is None:
-        errmsg = "An  error occurred while loading application {appname}"
+        errmsg = "An error occurred while loading application {appname}"
         if pf.GUI:
             if apps._traceback and pf.cfg['showapploaderrors']:
                 print(apps._traceback)
@@ -570,7 +575,7 @@ def runApp(appname, argv=[], refresh=False, lock=True, check=True):
     return res
 
 
-def runAny(appname=None, argv=[], step=False, refresh=False, remember=True):
+def runAny(appname=None, argv=[], step=False, refresh=False, remember=True, wait=False):
     """Run the current pyFormex application or script file.
 
     Parameters:
@@ -600,7 +605,7 @@ def runAny(appname=None, argv=[], step=False, refresh=False, remember=True):
     if utils.is_script(appname):
         return runScript(appname, argv)
     else:
-        return runApp(appname, argv, refresh)
+        return runApp(appname, argv, refresh, wait=wait)
 
 
 def exit(all=False):
