@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 2.1  (Sat Oct 24 14:52:22 CEST 2020)
+##  This file is part of pyFormex 2.2  (Wed Feb 10 14:59:35 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -72,6 +72,7 @@ stlb = 'Binary STL files (*.stl)'
 surface = 'Surface models (*.off *.gts *.stl)'
 tetsurf = 'Tetgen surface (*.smesh)'
 tetgen = 'Tetgen files (*.poly *.smesh *.ele *.face *.edge *.node *.neigh)'
+video = 'Video (*.mp4)'
 vtk = 'VTK types (*.vtk *.vtp)'
 vtp = 'vtkPolyData file (*.vtp)'
 
@@ -432,9 +433,9 @@ def command(cmd, verbose=True, check=True, **kargs):
     """Run an external command in a user friendly way.
 
     This is equivalent with the :func:`system` function but has
-    verbose=True and check=True options on by default.
+    verbose=True option on by default.
     """
-    return system(cmd, verbose=verbose, check=check, **kargs)
+    return system(cmd, verbose=verbose, **kargs)
 
 
 def killProcesses(pids, signal=15):
@@ -655,6 +656,7 @@ FileType('surface', 'Surface models', 'off', 'gts', 'stl')
 FileType('tetsurf', 'Tetgen surface', 'smesh')
 FileType('tetgen', 'Tetgen files', 'poly', 'smesh', 'ele', 'face',
          'edge', 'node', 'neigh')
+FileType('video', 'Video', 'mp4')
 FileType('vtk', 'VTK types', 'vtk', 'vtp')
 FileType('vtp', 'vtkPolyData file', 'vtp')
 
@@ -693,17 +695,16 @@ def fileDescription(ftype, compr=False):
     'Abaqus or CalCuliX input files (*.inp)'
     >>> fileDescription('doc')
     'DOC files (*.doc)'
-    >>> fileDescription('*.inp')
-    '*.inp'
+    >>> fileDescription('Video (*.mp4 *.ogv)')
+    'Video (*.mp4 *.ogv)'
     >>> fileDescription('pgf',compr=True)
     'pyFormex geometry files (*.pgf *.pgf.gz *.pgf.bz2)'
-
     """
     if isinstance(ftype, list):
-        return [FileTypes[f].desc(compr) for f in ftype]
-    ftype = ftype.lower()
-    if ftype in FileTypes:
-        ret = FileTypes[ftype].desc(compr)
+        return [fileDescription(f, compr) for f in ftype]
+    ltype = ftype.lower()
+    if ltype in FileTypes:
+        ret = FileTypes[ltype].desc(compr)
     elif ftype.isalnum():
         ret = f"{ftype.upper()} files (*.{ftype})"
     else:
@@ -839,7 +840,8 @@ def findIcon(name):
     icons/64x64/right.png
     >>> print(findIcon('xyz').relative_to(pf.cfg['pyformexdir']))
     icons/question.xpm
-
+    >>> print(findIcon('recording').relative_to(pf.cfg['pyformexdir']))
+    icons/recording.gif
     """
     for icondir in pf.cfg['gui/icondirs']:
         for icontype in pf.cfg['gui/icontypes']:
@@ -873,7 +875,7 @@ def listIconNames(dirs=None, types=None):
     >>> listIconNames([pf.cfg['icondir'] / '64x64'])[:4]
     ['down', 'ff', 'info', 'lamp']
     >>> listIconNames(types=['.xpm'])[:4]
-    ['clock', 'dist-angle', 'down', 'far']
+    ['clock', 'dist-angle', 'down', 'empty']
     """
     if dirs is None:
         dirs = pf.cfg['gui/icondirs']
@@ -1114,7 +1116,7 @@ class TempDir(tempfile.TemporaryDirectory):
     This is a wrapper around Python's tempfile.TemporaryDirectory,
     with the following differences:
 
-    - the default value for prefix is set to 'pyf_',
+    - the default value for prefix is set to ``pyf_``,
     - it has an extra attribute '.path' returning the directory name as a Path,
     - the context manager returns a Path instead of a str.
 
@@ -1340,6 +1342,56 @@ else:
 """ + text
 
 
+def convertText(text, format=''):
+    """Convert a text to a format recognized by Qt.
+
+    Input text format is plain, html or reStructuredText.
+    Output text format is plain or html, with reStructuredText being
+    converted to html.
+
+    Parameters
+    ----------
+    text: str
+        A multiline string in one of the supported formats:
+        plain text, html or reStructuredText.
+    format: str, optional
+        The format of the text: one of 'plain', 'html' ot 'rest'. The
+        default '' will autorecognize the supported formats.
+
+    Returns
+    -------
+    text: str
+        The converted text, being either plain or html.
+
+    Notes
+    -----
+    For the conversion of reStructuredText to work,
+    the Python docutils have to be installed on the system.
+
+    Examples
+    --------
+    >>> convertText('''..
+    ...     Header
+    ...     ------
+    ... ''').startswith('<?xml')
+    True
+    """
+    if format not in ['plain', 'html', 'rest']:
+        # autorecognition of 'rest'
+        if isinstance(text, str) and text.startswith('..'):
+            format = 'rest'
+
+    # conversion
+    if format == 'rest' and pf.cfg['gui/rst2html']:
+        # Try conversion to html
+        text = rst2html(text)
+
+    if isinstance(text, bytes):
+        text = text.decode()
+
+    return text
+
+
 def forceReST(text, underline=False):
     """Convert a text string to have it recognized as reStructuredText.
 
